#!/usr/bin/python3
# -*- coding: utf-8 -*-

### BEGIN LICENSE

# Copyright (C) 2013 National University of Defense Technology(NUDT) & Kylin Ltd

# Author:
#     Shine Huang<shenghuang@ubuntukylin.com>
# Maintainer:
#     Shine Huang<shenghuang@ubuntukylin.com>

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from utils import run
from models import enums
from models.application import BaseInfo
from models.globals import Globals
from utils.log_manager import LogManager
import gettext
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class ApkInfo(BaseInfo):

    def __init__(self, pkg_name, display_name, version, size, file_path, summary,is_notice = False):
        super().__init__(pkg_name)
        self.is_notice = is_notice
        self.app_id = 0
        self.pkgname = pkg_name
        self.displayname = display_name
        self.candidate_version = version
        self.category_name = ""
        self.category_name_cn = ""
        self.from_ukscdb = True
        self.version = version
        self.size = int(float(size))
        self.file_path = file_path
        self.summary_init = summary
        self.description_init = summary
        self.orig_name = pkg_name
        self.orig_summary = summary
        self.orig_description = summary
        self.thumbnail_url = None
        self.screenshot_url = None
        self.thumbnailfile = enums.UBUNTUKYLIN_RES_SCREENSHOT_PATH + pkg_name + "_thumbnail.png"
        self.screenshotfile = enums.UBUNTUKYLIN_RES_SCREENSHOT_PATH + pkg_name + "_screenshot.png"
        self.iconfile = enums.UBUNTUKYLIN_RES_ICON_PATH + pkg_name + ".png"
        self.screenshots = []
        self.screenshots_url = ""
        self.screenshots_updatetime = ""
        self.icons = []
        self.reviews = {}
        self.reivewpage = 0
        self.rnrStat = None
        self.ratings_average = 0
        self.ratings_total = 0
        self.review_total = 0
        self.downloadrank = 32767
        self.ratingrank = 32767
        self.pointoutrank = 32767
        self.recommendrank = 32767
        self.downloadcount = 0
        self.has_desktop = True
        self.arch = None
        self.system_name = None
        self.cpu_model = None
        self.no_cpu_model = None
        self.depends = None
        self.install_date = ''  # the date first install this app, get from server

        self.status = enums.PkgStates.NOTHING

        self.percent = 0

        self.installed_version = ''
        self.is_installed = False
        self.is_upgradable = False
        self.is_runnable = True
        self.is_removed = False

        self.kydroid_service = None

        self.package = None
        self.icon_path = ""
        self.down_cover_image_path = ""
        self.down_preview_image_path = ""
        self.initialsName = ""
        self.pinyinName = ""
        self.anotherName = ""
        self.certSubjectOu = ""
        self.softStyle = 3
        self.website = None
        self.manufacturers = ""
        self.init_screen_shot = False
        self.popularity = None

    @property
    def name(self):
        return self.pkgname

    @property
    def displayname_cn(self):
        return self.displayname

    @property
    def thumbnail(self):
        # self.thumbnail_url = SCREENSHOT_THUMB_URL % {
        #     'pkgname': self.pkgname,
        #     'version': self.version or 0,
        # }
        return self.thumbnail_url

    @property
    def screenshot(self):
        # self.screenshot_url = SCREENSHOT_LARGE_URL % {
        #     'pkgname': self.pkgname,
        #     'version': self.version or 0,
        # }
        return self.screenshot_url

    @property
    def description(self):
        return self.description_init

    @description.setter
    def description(self, description_set):
        self.description_init = description_set

    @property
    def summary(self):
        return self.summary_init

    @summary.setter
    def summary(self, summary_set):
        self.summary_init = summary_set

    @property
    def packageSize(self):
        return self.size

    @property
    def installedSize(self):
        return self.size

    @property
    def pkg_status(self):
        if (self.is_installed == False):
            return enums.PkgStates.UNINSTALLED
        else:
            if (self.is_upgradable == False):
                return enums.PkgStates.INSTALLED
            else:
                return enums.PkgStates.UPGRADABLE

    def run(self):
        if self.kydroid_service is not None:
            try:
                self.kydroid_service.launch_app(self.name)
            except:
                if (Globals.DEBUG_SWITCH):
                    #print("apk %s run error" % self.name)
                    Globals.LOG_ERROR.logger.error(_("apk %s run error" % self.name))

    def get_total_size(self):
        return self.size

    # get the reviews object list of this application
    def get_reviews(self, page):
        if page in self.reviews:
            return self.reviews[page]
        else:
            return None

    def add_reviews(self, page, reviewlist):
        if page not in self.reviews:
            self.reviews[page] = reviewlist

    def update_cache(self, apt_cache):
        pass


if __name__ == "__main__":
    pass



#!/usr/bin/python3
# -*- coding: utf-8 -*-

import os
import math
import time
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from models.application import *
from models.apkinfo import *
from utils.commontools import *
from models.enums import CACHE_DIR,BUTTON_PRESSED,BUTTON_ENTER,BUTTON_LEAVE,BUTTON_DISABLE,AppMsg,PageStates,ClickCard

class Advertisement_Widget(QFrame):
    ad_num = 0
    click_ad_card = pyqtSignal(Application,bool,int)
    click_ad_card_apk = pyqtSignal(ApkInfo,bool,int)
    click_none_app_ad_card = pyqtSignal()
    ad_move_left_time = QTimer()
    ad_move_right_time = QTimer()
    final_x_position = 0
    final_x_position2 = 0
    def __init__(self,w,h,w1,w2,mw,is_homepage = False,parent=None):
        QFrame.__init__(self, parent)
        self.dblist = []
        self.applist = []
        self.w = w
        self.h = h
        self.w1 = w1
        self.w2 = w2
        self.re_ad_w = w1
        self.re_ad_w2 = w2
        self.m_parent = parent
        self.is_homepage = is_homepage
        # self.w1 = int((self.width() - 20) * (self.w1 / (self.w - 20)))
        # self.w2 = int((self.width() - 20) * (self.w2 / (self.w - 20)))
        self.appmsg = None
        self.mw = mw
        self.init_ui()


    def init_ui(self):
        if(self.is_homepage):
            self.resize(self.w,self.h+20)
        else:
            self.resize(self.w,self.h)
        self.setWindowFlags(Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint)
        self.setAttribute(Qt.WA_TranslucentBackground)
        self.setFocusPolicy(Qt.NoFocus)
        self.setStyleSheet("QFrame{border:0px solid #ff0000;border-radius: 12px;background-color:transparent;}")

        self.ad_list_widget = QWidget(self)
        self.ad_list_widget.setWindowFlags(Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint)
        self.ad_list_widget.setAttribute(Qt.WA_TranslucentBackground)
        self.ad_list_widget.setStyleSheet("QFrame{border:0px solid #000000;border-radius: 12px;background-color:transparent;}")
        if (self.is_homepage):
            self.ad_list_widget.resize(self.w1+20,self.h+20)
            self.ad_list_widget.move(0, 0)
        else:
            self.ad_list_widget.resize(self.w1, self.h)
            self.ad_list_widget.move(0, 0)
        self.ad_list_widget.show()

        self.ad_list_widget2 = QWidget(self)
        self.ad_list_widget2.setWindowFlags(Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint)
        self.ad_list_widget2.setAttribute(Qt.WA_TranslucentBackground)
        self.ad_list_widget2.setStyleSheet("QFrame{border:0px solid #000000;border-radius: 12px;background-color:transparent;}")
        if (self.is_homepage):
            self.ad_list_widget2.resize(self.w2+20,self.h+20)
            self.ad_list_widget2.move(self.ad_list_widget.width(), 0)
        else:
            self.ad_list_widget2.resize(self.w2, self.h+20)
            self.ad_list_widget2.move(self.ad_list_widget.width() + 20, 0)

    def re_move(self,proportion):
        if (self.is_homepage):
            w1 = int((self.width() -20)*(self.w1/(self.w-20)))
            w2 = int((self.width() - 20) * (self.w2 / (self.w - 20)))
            self.re_ad_w = w1
            self.re_ad_w2 = w2
            self.ad_list_widget.resize(w1+20,self.height())
            self.ad_list_widget2.resize(w2+20,self.height())
            self.ad_list_widget.move(0, 0)
            self.ad_list_widget2.move(self.ad_list_widget.width() , 0)
            ads = self.ad_list_widget.children()
            for i in ads:
                i.resize(w1-20, self.height()-20)
                i.get_ad_background()
                i.move(10,10)
            ads = self.ad_list_widget2.children()
            for i in ads:
                i.resize(w2-20, self.height()-20)
                i.get_ad_background()
                i.move(10,10)
            self.ad_list_widget2.move(self.ad_list_widget.x()+self.ad_list_widget.width(),0)
        else:
            w1 = int((self.width() - 20) * (self.w1 / (self.w - 20)))
            w2 = int((self.width() - 20) * (self.w2 / (self.w - 20)))
            self.re_ad_w = w1
            self.re_ad_w2 = w2
            self.ad_list_widget.resize(w1, self.height())
            self.ad_list_widget2.resize(w2, self.height())
            self.ad_list_widget.move(0, 0)
            self.ad_list_widget2.move(self.ad_list_widget.width() + 20, 0)
            ads = self.ad_list_widget.children()
            for i in ads:
                i.resize(w1, self.height())
                i.get_ad_background()
                i.move(0, 0)
            ads = self.ad_list_widget2.children()
            for i in ads:
                i.resize(w2, self.height())
                i.get_ad_background()
                i.move(0, 0)
            self.ad_list_widget2.move(self.ad_list_widget.x() + self.ad_list_widget.width() + 20, 0)

    def get_lists(self,dblist,applist):
        self.applist = applist
        self.dblist = dblist

    def add_ad_widget(self,image_url,appmsg,ad_count,num):
        if(self.is_homepage):
            if(num == 0):
                itemwidget = Ad_Widget(self.re_ad_w, self.height()-20, image_url, appmsg, False,self.is_homepage,self.ad_list_widget)
                itemwidget.clicked_ad_card.connect(lambda :self.slot_click_ad_card(itemwidget.appmsg))
                itemwidget.move(10, 10)
                itemwidget.resize(self.width() - 60-20, self.height()-20)
                self.ad_list_widget.move(0, 0)
                self.ad_list_widget.show()
                self.ad_list_widget2.show()
                # self.re_move(1)
            else:
                itemwidget = Ad_Widget(self.re_ad_w2, self.height()-20, image_url, appmsg,True, self.is_homepage,self.ad_list_widget2)
                itemwidget.clicked_ad_card.connect(lambda :self.slot_click_ad_card(itemwidget.appmsg))
                itemwidget.move(10, 10)
                itemwidget.resize(self.width() - 60-20, self.height()-20)
                self.ad_list_widget.move(0, 0)
                self.ad_list_widget.show()
                self.ad_list_widget2.show()
                # self.re_move(1)
        else:
            if (num == 0):
                itemwidget = Ad_Widget(self.re_ad_w, self.height(), image_url, appmsg, False,self.is_homepage, self.ad_list_widget)
                itemwidget.clicked_ad_card.connect(lambda: self.slot_click_ad_card(itemwidget.appmsg))
                itemwidget.move(0, 0)
                itemwidget.resize(self.width() - 60, self.height())
                self.ad_list_widget.move(0, 0)
                self.ad_list_widget.show()
                self.ad_list_widget2.show()
                # self.re_move(1)
            else:
                itemwidget = Ad_Widget(self.re_ad_w2, self.height(), image_url, appmsg, True, self.is_homepage,self.ad_list_widget2)
                itemwidget.clicked_ad_card.connect(lambda: self.slot_click_ad_card(itemwidget.appmsg))
                itemwidget.move(0, 0)
                itemwidget.resize(self.width() - 60, self.height())
                self.ad_list_widget.move(0, 0)
                self.ad_list_widget.show()
                self.ad_list_widget2.show()
                # self.re_move(1)

    def change_ad_image(self,image_url,appmsg,ad_count,num):
        if(num == 0):
            for ad_widget in self.ad_list_widget.children():
                ad_widget.image_url = image_url
                ad_widget.appmsg = appmsg
                ad_widget.ad_background()
        else:
            if (num == 0):
                for ad_widget in self.ad_list_widget2.children():
                    ad_widget.image_url = image_url
                    ad_widget.appmsg = appmsg
                    ad_widget.ad_background()

    #
    # 函数：处理点击卡片
    #
    def slot_click_ad_card(self ,app_msg):
        if(app_msg != None):
            if(Globals.NOWPAGE == PageStates.HOMEPAGE):
                self.mw.save_click_ad_card(app_msg.app_id,0)
            elif(Globals.NOWPAGE == PageStates.CAREGORYPAGE):
                for i in Globals.ALL_CATEGORIES:
                    if (i["name"] == self.mw.detailwidget.category_widget.type_name_label.text()):
                        self.mw.save_click_ad_card(app_msg.app_id,i["id"])
                        break
                    elif (i["displayname"] == self.mw.detailwidget.category_widget.type_name_label.text()):
                        self.mw.save_click_ad_card(app_msg.app_id, i["id"])
                        break
            if(type(app_msg) == Application):
                self.click_ad_card.emit(app_msg,True,ClickCard.AD)
            else:
                self.click_ad_card_apk.emit(app_msg,True,ClickCard.AD)
        # else:
            # self.click_none_app_ad_card.emit()


class Ad_Widget(QFrame):
    big_width = 1263
    small_width = 578
    get_height = 384
    appmsg = []
    image_url = ""
    clicked_ad_card = pyqtSignal()
    def __init__(self,w,h,image_url,appmsg,is_big,is_homepage,parent=None):
        QFrame.__init__(self, parent)
        self.appmsg = appmsg
        self.w = w
        self.h = h
        self.is_homepage = is_homepage
        self.is_big = is_big
        self.image_url = image_url
        self.init_ui()
        self.m_parent = parent
        # print("start change imag",time.strftime("%Y-%m-%dT%H:%M:%SZ", time.localtime()))
        self.ad_background()
        # print("end change imag", time.strftime("%Y-%m-%dT%H:%M:%SZ", time.localtime()))
        self.show()

    def init_ui(self):
        self.resize(self.w,self.h)
        self.setWindowFlags(Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint)
        self.setAttribute(Qt.WA_TranslucentBackground)
        self.setFocusPolicy(Qt.NoFocus)
        self.setStyleSheet("QFrame{border:0px solid  #ffffff;border-radius: 12px;background-color:#FFFFFF;}")

        self.icon_label = QLabel(self)
        # self.icon_label.setAttribute(Qt.WA_TranslucentBackground)
        self.icon_label.resize(self.w,self.h)
        self.icon_label.move(0,0)

        self.hover_widget = QWidget(self)
        self.hover_widget.resize(self.w,self.h)
        self.hover_widget.setWindowFlags(Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint)
        # self.card_list_widget.setAttribute(Qt.WA_TranslucentBackground)
        self.hover_widget.setStyleSheet("QWidget{background: rgba(0, 0, 0, 0.1);border-radius: 12px;}")
        self.hover_widget.move(0, 0)
        self.hover_widget.hide()


    def ad_background(self):
        self.icon_label.resize(self.width(), self.height())
        self.icon_label.move(0, 0)
        self.hover_widget.setFixedSize(self.width(), self.height())
        self.hover_widget.move(0, 0)
        #imagepath = os.path.join(CACHE_DIR,self.image_url)
        if(self.appmsg != None):
            if(self.image_url!= None):
                if(os.path.isfile(self.image_url) == False):
                    file_path_list = self.image_url.split("/")
                    file_name = file_path_list[len(file_path_list)-1]
                    self.image_url = get_ads_image(file_name)
            # self.icon_label.setStyleSheet(
            #     "QLabel{border-radius: 12px;border-image: url('" + self.image_url + "') 0 0 0 0 stretch strectch;}")
            # self.icon_label.setStyleSheet(
            #     "QLabel{border-radius: 12px;border-image: url('" + self.image_url + "');}")
            if(self.image_url != None):
                self.icon_label.setStyleSheet("QLabel{border-radius: 12px;}")
                if(Globals.DEVICE == 1):
                    self.pix2 = QPixmap(self.image_url)
                    if(self.is_big):
                        #IgnoreAspectRatio:忽略横纵比    SmoothTransformation：平滑变换
                        self.fitpixmap_userIcon = self.pix2.scaled(self.width()+2, self.height()+2, Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
                        self.fitpixmap_userIcon = self.PixmapToRound(self.fitpixmap_userIcon, self.width(), self.height())
                    else:
                        self.fitpixmap_userIcon = self.pix2.scaled(self.width()+2, self.height()+2,
                                                                   Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
                        self.fitpixmap_userIcon = self.PixmapToRound(self.fitpixmap_userIcon, self.width(), self.height())
                    self.icon_label.setPixmap(self.fitpixmap_userIcon)
                else:
                    self.icon_label.setStyleSheet("QLabel{border-image:url('"+self.image_url+"');border-radius: 12px;}")
            else:
                # self.setStyleSheet("QFrame{border:0px solid  #ffffff;border-radius: 12px;background-color:#F4F4F4;}")
                self.icon_label.setStyleSheet("QLabel{background-image:url(./res/ad_default.png);border-radius: 12px;}")
            # # self.icon_label.show()
            # # self.show()
        else:
            self.image_url = None
            self.icon_label.setStyleSheet("QLabel{background-image:url(./res/ad_default.png);background-repeat:no-repeat;background-position:center;background-color:#F4F4F4;border-radius: 12px;}")
        self.icon_label.setScaledContents(True)


    def get_ad_background(self):
        self.icon_label.resize(self.width(), self.height())
        self.icon_label.move(0, 0)
        self.hover_widget.setFixedSize(self.width(), self.height())
        self.hover_widget.move(0, 0)
        # imagepath = os.path.join(CACHE_DIR,self.image_url)
        if(self.image_url != None):
            if (os.path.isfile(self.image_url) == False):
                file_path_list = self.image_url.split("/")
                file_name = file_path_list[len(file_path_list) - 1]
                self.image_url = get_ads_image(file_name)
            # self.icon_label.setStyleSheet(
            #     "QLabel{border-radius: 12px;border-image: url('" + self.image_url + "') 0 0 0 0 stretch strectch;}")
            if (Globals.DEVICE == 1):
                self.icon_label.setStyleSheet("QLabel{border-radius: 12px;}")
                self.pix2 = QPixmap(self.image_url)
                self.fitpixmap_userIcon = self.pix2.scaled(self.icon_label.width(), self.icon_label.height(),
                                                           Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
                self.fitpixmap_userIcon = self.PixmapToRound(self.fitpixmap_userIcon, self.width(), self.height())
                self.icon_label.setPixmap(self.fitpixmap_userIcon)
                self.icon_label.setScaledContents(True)
            else:
                self.icon_label.setStyleSheet("QLabel{border-image:url('" + self.image_url + "');border-radius: 12px;}")
            # palette = QPalette()
            # pix = QPixmap(self.image_url)
            # pix = pix.scaled(self.width(), self.height())
            # palette.setBrush(QPalette.Background, QBrush(pix))
            # self.icon_label.setPalette(palette)


    def PixmapToRound(self,src,x,y):
        pixmapa = QPixmap(src)
        pixmap = QPixmap(x, y)
        # pixmap.fill(Qt.transparent)
        pixmap.fill(Qt.transparent)
        painter = QPainter(pixmap)
        painter.setRenderHint(QPainter.Antialiasing, True)
        #QPainter.Antialiasing:抗锯齿
        #QPainter.SmoothPixmapTransform：在对图片进行缩放时启用线性插值算法而不是最邻近算法
        # painter.setRenderHints(QPainter.Antialiasing | QPainter.SmoothPixmapTransform)
        path = QPainterPath()
        rect = QRectF(0,0,x,y)
        path.addRoundedRect(rect, 12.0, 12.0)
        painter.setClipPath(path)
        painter.drawPixmap(0, 0, x, y, pixmapa)

        return pixmap

    def paintEvent(self, QPaintEvent):
        paint = QPainter(self)
        paint.setRenderHint(QPainter.Antialiasing)

# 鼠标进入事件

    def enterEvent(self, event):
        self.status = BUTTON_ENTER
        if(self.appmsg != None):
            self.hover_widget.show()
            if(self.is_homepage):
                self.setGeometry(int(self.x()), int(self.y()), self.width(), self.height())
                self.shadow = QGraphicsDropShadowEffect(self)
                self.shadow.setOffset(0, 0)
                self.shadow.setColor(QColor(qRgba(149, 149, 149, 0)))
                self.shadow.setBlurRadius(12)
                self.setGraphicsEffect(self.shadow)

    #
    # 函数：鼠标离开事件
    #

    def leaveEvent(self, event):
        self.status = BUTTON_LEAVE
        if (self.is_homepage):
            self.resize(self.width(), self.height())
            self.shadow = QGraphicsDropShadowEffect(self)
            self.shadow.setBlurRadius(0)
            self.shadow.setOffset(0, 0)
            self.setGraphicsEffect(self.shadow)
        self.hover_widget.hide()

    #
    # 函数：鼠标按下事件
    #
    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:
            self.status = BUTTON_PRESSED
            self.clicked_ad_card.emit()
        else:
            event.ignore()



#!/usr/bin/python3
# -*- coding: utf-8 -*-


from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from models.enums import BUTTON_DISABLE,BUTTON_PRESSED,BUTTON_LEAVE,BUTTON_ENTER,AppMsg
from utils import commontools
from models.application import *

class uninstall_btn(QFrame):
    def __init__(self, parent=None):
        QWidget.__init__(self, parent)
        self.m_parent = parent
        self.currentpage = 0
        self.ngif = []
        self.resize(22,22)
        self.setWindowFlags(Qt.FramelessWindowHint)
        self.setAttribute(Qt.WA_TranslucentBackground, True)
        self.setProperty("doNotBlur", True)
        self.setProperty("blurRegion", QRegion(QRect(0, 0, 1, 1)))

        self.switchTimer = QTimer(self)
        self.switchTimer.timeout.connect(self.slot_switch_animation_step)
        self.loadinggif = QLabel(self)
        self.loadinggif.setAttribute(Qt.WA_TranslucentBackground)
        self.loadinggif.resize(22,22)
        self.loadinggif.move(0,0)
        self.load_png()


    #
    # 函数名:加载图片
    # Function: load png
    #
    def load_png(self):
        for i in range(1, 17):
            img = QPixmap("res/uninstall/" + str(i) + ".png")
            self.ngif.append(img)

    #
    # 函数名:更改
    # Function: process change
    #
    def slot_switch_animation_step(self):
        if (self.currentpage == 16):
            self.currentpage = 0

        self.loadinggif.setPixmap(self.ngif[self.currentpage])
        self.loadinggif.setScaledContents(True)
        self.currentpage = self.currentpage + 1

    #
    # 函数名:开始加载
    # Function: start loading
    #
    def start_loading(self):
        self.currentpage = 0
        self.switchTimer.start(60)
        self.show()

    #
    # 函数名:停止加载
    # Function: stop loading
    #
    def stop_loading(self):
        self.switchTimer.stop()
        self.hide()



#!/usr/bin/python3
# -*- coding: utf-8 -*-


from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from models.globals import *
from models.enums import (BUTTON_ENTER, BUTTON_LEAVE, BUTTON_PRESSED, BUTTON_DISABLE)
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class Opration_Btn(QPushButton):

    def __init__(self):
        self.text_label = QLabel(self)
        self.text_label.setAttribute(Qt.WA_TranslucentBackground)
        self.text_label.move(12,6)


import os
import math
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from ui.systembutton import *
from models.enums import CACHE_DIR,BUTTON_PRESSED,BUTTON_ENTER,BUTTON_LEAVE,BUTTON_DISABLE
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class Configure_Widget(QWidget):
    def __init__(self,parent = None):
        QWidget.__init__(self, parent)
        self.mouse_press = False
        self.mw = parent
        self.init_ui()
        self.paintEvent = self.set_paintEvent

    def init_ui(self):
        self.setFixedSize(442,240)
        self.setWindowFlags(Qt.FramelessWindowHint | Qt.Tool)
        self.setWindowTitle(_("Software Store"))
        self.setAttribute(Qt.WA_TranslucentBackground)
        self.widget = QWidget(self)
        self.widget.resize(424,222)
        self.widget.move(9,9)
        #self.widget.setStyleSheet("QWidget{background: rgba(255, 255, 255, 0.7);border-radius:12px;background-color:#ffffff;}")
        self.title_label = QLabel(self.widget)
        self.title_label.setFixedSize(170,16)
        self.title_label.setText(_("Server address"))
        self.title_label.setStyleSheet("QLabel{border:0px;font-size: 14px;font-weight: 500;color: #1B1B1B;line-height: 14px;}")
        self.title_label.move(16,12)

        self.line_label = QLabel(self.widget)
        self.line_label.setFixedSize(422, 1)
        self.line_label.setStyleSheet("QLabel{width: 424px;height: 1px;background: #F2F6FD;}")
        self.line_label.move(1, 38)

        self.close_btn = QPushButton(self.widget)
        self.close_btn.setFocusPolicy(Qt.NoFocus)
        self.close_btn.resize(30,30)
        self.close_btn.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/close1.png')}QPushButton:hover{border:0px;border-image:url('res/close2.png')}QPushButton:pressed{border:0px;border-image:url('res/close3.png')}")
        self.close_btn.move(self.widget.width()-self.close_btn.width()-4,4)
        self.close_btn.installEventFilter(self)
        self.close_btn.setToolTip(_("close"))

        self.software_label = QLabel(self.widget)
        self.software_label.setWordWrap(True)
        self.software_label.setAlignment(Qt.AlignLeft)
        self.software_label.setText(_("Software Store")+":")
        self.software_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;background:transparent;}")
        self.software_label.adjustSize()
        self.software_label.move(16,self.line_label.y()+self.line_label.height()+22)

        self.service_dress_label = QLineEdit(self.widget)
        self.service_dress_label.installEventFilter(self)
        if(Globals.LAN == "zh_CN"):
            self.service_dress_label.resize(324,32)
        else:
            self.service_dress_label.resize(280, 32)
        # self.service_dress_label.setStyleSheet(
        #     "QLineEdit{font-size: 14px;font-family: PingFangSC-Regular, PingFang SC;font-weight: 400;color: #1B1B1B;line-height: 24px;background:#E6E6E6;border: 1px solid ##E6E6E6;border-radius: 4px;}")
        # self.service_dress_label.setPlaceholderText(_("Please input the server address of the software store"))
        self.service_dress_label.move(self.software_label.x()+self.software_label.width()+8,self.line_label.y()+self.line_label.height()+16)

        self.service_dress_back_label = QLabel(self.widget)
        self.service_dress_back_label.setText(_("Please input the server address of the software store"))
        self.service_dress_back_label.setStyleSheet(
            "QLabel{border:0px;font-size: 14px;font-weight: 400;color: #8F9399;line-height: 16px;border:0px;background-color: transparent;}")
        # self.search_line.setMaxLength(30)
        self.service_dress_back_label.setAttribute(Qt.WA_TranslucentBackground)
        self.service_dress_back_label.setEnabled(False)
        self.service_dress_back_label.setFixedHeight(20)
        self.service_dress_back_label.setMaximumWidth(self.service_dress_label.width()-10)
        self.service_dress_back_label.adjustSize()
        self.service_dress_back_label.move(self.service_dress_label.x() + 8, self.service_dress_label.y() + int(
            (self.service_dress_label.height() - self.service_dress_back_label.height()) / 2))
        self.service_dress_label.raise_()

        self.tip_label = QLabel(self.widget)
        self.tip_label.setText(_("Please enter the correct server address"))
        self.tip_label.setStyleSheet("QLabel{font-size: 12px;font-weight: 400;color: #F56C6C;line-height: 17px;}")
        self.tip_label.adjustSize()
        self.tip_label.move(self.service_dress_label.x(),self.service_dress_label.height()+self.service_dress_label.y()+4)
        self.tip_label.hide()

        self.kylin_id_label = QLabel(self.widget)
        self.kylin_id_label.setWordWrap(True)
        self.kylin_id_label.resize(self.software_label.width(),self.software_label.height())
        self.kylin_id_label.setAlignment(Qt.AlignRight)
        self.kylin_id_label.setText(_("Kylin ID") + ":")
        self.kylin_id_label.setStyleSheet(
            "QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;background:transparent;}")
        # self.kylin_id_label.adjustSize()
        self.kylin_id_label.move(16, self.line_label.y() + self.line_label.height() + 79)

        self.kylinid_dress_label = QLineEdit(self.widget)
        self.kylinid_dress_label.installEventFilter(self)
        if (Globals.LAN == "zh_CN"):
            self.kylinid_dress_label.resize(324, 32)
        else:
            self.kylinid_dress_label.resize(280, 32)
        # self.kylinid_dress_label.setStyleSheet("QLineEdit{font-size: 14px;font-family: PingFangSC-Regular, PingFang SC;font-weight: 400;color: #1B1B1B;line-height: 24px;background:#E6E6E6;border: 1px solid ##E6E6E6;border-radius: 4px;}")
        # self.kylinid_dress_label.setPlaceholderText(_("Please input the server address of the Kylin ID"))
        self.kylinid_dress_label.move(self.kylin_id_label.x() + self.kylin_id_label.width() + 8,
                                      self.line_label.y() + self.line_label.height() + 73)

        self.kylinid_dress_back_label = QLabel(self.widget)
        self.kylinid_dress_back_label.setText(_("Please input the server address of the software store"))
        self.kylinid_dress_back_label.setStyleSheet(
            "QLabel{border:0px;font-size: 14px;font-weight: 400;color: #8F9399;line-height: 16px;border:0px;background-color: transparent;}")
        # self.search_line.setMaxLength(30)
        self.kylinid_dress_back_label.setAttribute(Qt.WA_TranslucentBackground)
        self.kylinid_dress_back_label.setEnabled(False)
        self.kylinid_dress_back_label.setMaximumWidth(self.kylinid_dress_label.width() - 10)
        self.kylinid_dress_back_label.setFixedHeight(20)
        self.kylinid_dress_back_label.adjustSize()
        self.kylinid_dress_back_label.move(self.kylinid_dress_label.x() + 8, self.kylinid_dress_label.y() + int((self.kylinid_dress_label.height()-self.kylinid_dress_back_label.height())/2))
        self.kylinid_dress_label.raise_()

        self.tip_label2 = QLabel(self.widget)
        self.tip_label2.setText(_("Please enter the correct server address"))
        self.tip_label2.setStyleSheet("QLabel{font-size: 12px;font-weight: 400;color: #F56C6C;line-height: 17px;}")
        self.tip_label2.adjustSize()
        self.tip_label2.move(self.kylinid_dress_label.x(),
                            self.kylinid_dress_label.height() + self.kylinid_dress_label.y() + 4)
        self.tip_label2.hide()

        self.btn = QPushButton(self.widget)
        self.btn.setFocusPolicy(Qt.NoFocus)
        self.btn.setFixedSize(64,30)
        self.btn.setStyleSheet("QPushButton{background: #3790FA;border-radius: 6px;font-size: 14px;font-weight: 400;color: #FFFFFF;text-align: center;line-height: 12px;}QPushButton:hover{background: #40A9FB;;border-radius: 6px;color: #ffffff;}QPushButton:pressed{background: #296CD9;border-radius: 6px;color: #ffffff;}")
        self.btn.setText(_("OK"))
        self.btn.move(self.widget.width() - self.btn.width() - 16,self.line_label.y() + self.line_label.height() + 129)

        self.cancel_btn = QPushButton(self.widget)
        self.cancel_btn.setFocusPolicy(Qt.NoFocus)
        self.cancel_btn.setFixedSize(64, 30)
        self.cancel_btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 20px;border-radius: 6px;text-align: center;border: 1px solid #DDDFE7;}QPushButton:hover{background: #F2F6FD;border-radius: 6px;border: 1px solid #DDDFE7;}QPushButton:pressed{background: #F2F6FD;border-radius: 6px;border: 1px solid #DDDFE7;}")
        self.cancel_btn.setText(_("cancel"))
        self.cancel_btn.move(self.btn.x() - self.cancel_btn.width() - 16, self.btn.y())
        self.cancel_btn.show()

        self.slot_show_dark_mode()

    #
    # 函数：处理主题颜色的显示
    #
    def slot_show_dark_mode(self):
        if (Globals.THEME_COLOR == 0):
            if(Globals.RIGHT_ANGLE):
                self.widget.setStyleSheet(".QWidget{background-color:#ffffff;border: 1px solid rgba(38, 38, 38, 0.15);}")
                self.setStyleSheet("QFrame{background-color:#ffffff;}")
            else:
                self.widget.setStyleSheet(".QWidget{border-radius:12px;background-color:#ffffff;border: 1px solid rgba(38, 38, 38, 0.15);}")
                self.setStyleSheet("QFrame{background-color:#ffffff;}")
            self.title_label.setStyleSheet("QLabel{font-size: 14px;color: #1B1B1B;font-weight: 500;background:transparent;}")
            self.software_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;background:transparent;}")
            self.kylin_id_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;background:transparent;}")
            self.service_dress_label.setStyleSheet(
                "QLineEdit{font-size: 14px;font-weight: 400;color: #1B1B1B;line-height: 24px;background:#E6E6E6;border: 1px solid #E6E6E6;border-radius: 6px;}QLineEdit:hover{width: 160px;height: 36px;border-radius: 6px;border: 1px solid #3790FA;background:#E6E6E6;}QLineEdit:pressed{width: 160px;height: 36px;border-radius: 6px;border: 2px solid #3790FA;background:transparent;}")
            self.kylinid_dress_label.setStyleSheet(
                "QLineEdit{font-size: 14px;font-weight: 400;color: #1B1B1B;line-height: 24px;background:#E6E6E6;border: 1px solid #E6E6E6;border-radius: 6px;}QLineEdit:hover{width: 160px;height: 36px;border-radius: 6px;border: 1px solid #3790FA;background:#E6E6E6;}QLineEdit:pressed{width: 160px;height: 36px;border-radius: 6px;border: 2px solid #3790FA;background:transparent;}")
            self.line_label.setStyleSheet("QLabel{width: 424px;height: 1px;background: #F2F6FD;}")
            self.service_dress_back_label.setStyleSheet(
                "QLabel{border:0px;font-size: 14px;font-weight: 400;color: #8F9399;line-height: 16px;border:0px;background-color: transparent;}")
            self.kylinid_dress_back_label.setStyleSheet(
                "QLabel{border:0px;font-size: 14px;font-weight: 400;color: #8F9399;line-height: 16px;border:0px;background-color: transparent;}")
            self.close_btn.setStyleSheet("QPushButton{border-radius: 4px;border:0px;border-image:url('res/close1.png')}QPushButton:hover{border:0px;border-image:url('res/close2.png')}QPushButton:pressed{border:0px;border-image:url('res/close3.png')}")
        else:
            if (Globals.RIGHT_ANGLE):
                self.widget.setStyleSheet(".QWidget{background-color:#3D3D41;border: 1px solid rgba(38, 38, 38, 0.15);}")
                self.setStyleSheet("QFrame{background-color:#1F2022;}")
            else:
                self.setStyleSheet("QFrame{background-color:#1F2022;}")
                self.widget.setStyleSheet(".QWidget{border-radius:12px;background-color:#3D3D41;border: 1px solid rgba(38, 38, 38, 0.15);}")
            self.title_label.setStyleSheet("QLabel{font-size: 14px;color: #8F9399;font-weight: 500;line-height: 14px;background:transparent;}")
            self.software_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 20px;background:transparent;}")
            self.kylin_id_label.setStyleSheet(
                "QLabel{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 20px;background:transparent;}")
            self.line_label.setStyleSheet("QLabel{width: 424px;height: 1px;background: #48484C;}")
            self.service_dress_back_label.setStyleSheet(
                "QLabel{border:0px;font-size: 14px;font-weight: 400;color: #8F9399;line-height: 16px;border:0px;background-color: transparent;}")
            self.kylinid_dress_back_label.setStyleSheet(
                "QLabel{border:0px;font-size: 14px;font-weight: 400;color: #8F9399;line-height: 16px;border:0px;background-color: transparent;}")
            self.service_dress_label.setStyleSheet(
                "QLineEdit{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 24px;background:#373737;border: 1px solid #373737;border-radius: 6px;}QLineEdit:hover{width: 160px;height: 36px;border-radius: 6px;border: 1px solid #3790FA;background:transparent;}QLineEdit:pressed{width: 160px;height: 36px;border-radius: 6px;border: 2px solid #3790FA;background:transparent;}")
            self.kylinid_dress_label.setStyleSheet(
                "QLineEdit{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 24px;background:#373737;border: 1px solid #373737;border-radius: 6px;}QLineEdit:hover{width: 160px;height: 36px;border-radius: 6px;border: 1px solid #3790FA;background:transparent;}QLineEdit:pressed{width: 160px;height: 36px;border-radius: 6px;border: 2px solid #3790FA;background:transparent;}")
            self.close_btn.setStyleSheet(
                "QPushButton{border-radius: 4px;border:0px;border-image:url('res/common-close-white.png')}QPushButton:hover{border:0px;border-image:url('res/hover-close.png')}QPushButton:pressed{border:0px;border-image:url('res/clicked-close.png')}")
        # QApplication.processEvents()

    #
    # 函数：处理点击关闭按钮
    #
    def slot_click_close_btn(self):
        if (Globals.THEME_COLOR == 0):
            self.close_btn.setStyleSheet(
                "QPushButton{border-radius: 4px;border:0px;border-image:url('res/close1.png')}")
        else:
            self.close_btn.setStyleSheet(
                "QPushButton{border-radius: 4px;border:0px;border-image:url('res/res/common-close-white.png.png')}")
        self.hide()
        QApplication.setActiveWindow(self.mw)

    def eventFilter(self, widget, event):
        if(hasattr(self,"service_dress_label")):
            if(widget == self.service_dress_label and event.type() == event.FocusIn):
                if (Globals.THEME_COLOR == 0):
                    self.service_dress_label.setStyleSheet(
                        "QLineEdit{width: 160px;height: 36px;border-radius: 6px;border: 2px solid #3790FA;background:transparent;color: #1B1B1B;}")
                else:
                    self.service_dress_label.setStyleSheet(
                        "QLineEdit{width: 160px;height: 36px;border-radius: 6px;border: 2px solid #3790FA;background:transparent;color:#FFFFFF;}")
                return False
            elif(widget == self.service_dress_label and event.type() == event.FocusOut):
                if (Globals.THEME_COLOR == 0):
                    self.service_dress_label.setStyleSheet("QLineEdit{font-size: 14px;font-weight: 400;color: #1B1B1B;line-height: 24px;background:#E6E6E6;border: 1px solid #E6E6E6;border-radius: 6px;}QLineEdit:hover{width: 160px;height: 36px;border-radius: 6px;border: 1px solid #3790FA;background:#E6E6E6;}QLineEdit:pressed{width: 160px;height: 36px;border-radius: 6px;border: 2px solid #3790FA;background:transparent;}")
                else:
                    self.service_dress_label.setStyleSheet("QLineEdit{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 24px;background:#373737;border: 1px solid #373737;border-radius: 6px;}QLineEdit:hover{width: 160px;height: 36px;border-radius: 6px;border: 1px solid #3790FA;background:transparent;}QLineEdit:pressed{width: 160px;height: 36px;border-radius: 6px;border: 2px solid #3790FA;background:transparent;}")

                return False

        if (hasattr(self, "kylinid_dress_label")):
            if (widget == self.kylinid_dress_label and event.type() == event.FocusIn):
                if (Globals.THEME_COLOR == 0):
                    self.kylinid_dress_label.setStyleSheet(
                        "QLineEdit{width: 160px;height: 36px;border-radius: 6px;border: 2px solid #3790FA;background:transparent; color: #1B1B1B;}")
                else:
                    self.kylinid_dress_label.setStyleSheet(
                        "QLineEdit{width: 160px;height: 36px;border-radius: 6px;border: 2px solid #3790FA;background:transparent;color:#FFFFFF;}")
                return False
            elif (widget == self.kylinid_dress_label and event.type() == event.FocusOut):
                if (Globals.THEME_COLOR == 0):
                    self.kylinid_dress_label.setStyleSheet(
                        "QLineEdit{font-size: 14px;font-weight: 400;color: #1B1B1B;line-height: 24px;background:#E6E6E6;border: 1px solid #E6E6E6;border-radius: 6px;}QLineEdit:hover{width: 160px;height: 36px;border-radius: 6px;border: 1px solid #3790FA;background:#E6E6E6;}QLineEdit:pressed{width: 160px;height: 36px;border-radius: 6px;border: 2px solid #3790FA;background:transparent;}")
                else:
                    self.kylinid_dress_label.setStyleSheet(
                        "QLineEdit{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 24px;background:#373737;border: 1px solid #373737;border-radius: 6px;}QLineEdit:hover{width: 160px;height: 36px;border-radius: 6px;border: 1px solid #3790FA;background:transparent;}QLineEdit:pressed{width: 160px;height: 36px;border-radius: 6px;border: 2px solid #3790FA;background:transparent;}")
                return False
            pass
        if (hasattr(self, "close_btn")):
            if (widget == self.close_btn and event.type() == event.MouseButtonRelease):
                self.slot_click_close_btn()
                # return True
            elif (widget == self.close_btn and event.type() == event.HoverEnter):
                if (Globals.THEME_COLOR == 0):
                    self.close_btn.setStyleSheet(
                        "QPushButton:hover{border-radius: 4px;border:0px;border-image:url('res/close2.png')}")
                else:
                    self.close_btn.setStyleSheet(
                        "QPushButton{border-radius: 4px;border:0px;border-image:url('res/hover-close.png')}")
            elif (widget == self.close_btn and event.type() == event.HoverLeave):
                if (Globals.THEME_COLOR == 0):
                    self.close_btn.setStyleSheet(
                        "QPushButton{border-radius: 4px;border:0px;border-image:url('res/close1.png')}")
                else:
                    self.close_btn.setStyleSheet(
                        "QPushButton{border-radius: 4px;border:0px;border-image:url('res/common-close-white.png')}")
            elif (widget == self.close_btn and event.type() == event.MouseButtonPress):
                if (Globals.THEME_COLOR == 0):
                    self.close_btn.setStyleSheet(
                        "QPushButton:hover{border-radius: 4px;border:0px;border-image:url('res/close3.png')}")
                else:
                    self.close_btn.setStyleSheet(
                        "QPushButton{border-radius: 4px;border:0px;border-image:url('res/clicked-close.png')}")

        return False

    #
    # 函数：重绘函数
    #
    def set_paintEvent(self, event):
        painter = QPainter(self)
        m_defaultBackgroundColor = QColor(qRgba(0, 0, 0, 16))
        m_defaultBackgroundColor.setAlpha(16)
        path = QPainterPath()
        path.setFillRule(Qt.WindingFill)
        path.addRoundedRect(10, 10, self.width() - 20, self.height() - 20, 12, 12)

        painter.setRenderHint(QPainter.Antialiasing, True)
        painter.fillPath(path, QBrush(QColor(m_defaultBackgroundColor.red(),
                                             m_defaultBackgroundColor.green(),
                                             m_defaultBackgroundColor.blue(),
                                             m_defaultBackgroundColor.alpha())))

        color = QColor(0, 0, 0, 16)
        i = 0
        while i < 4:
            path = QPainterPath()
            path.setFillRule(Qt.WindingFill)
            path.addRoundedRect(10 - i, 10 - i, self.width() - (10 - i) * 2, self.height() - (10 - i) * 2, 12, 12)
            color.setAlpha(int(100 - math.sqrt(i) * 50))
            painter.setPen(color)
            painter.drawPath(path)
            i = i + 1

        painter.setRenderHint(QPainter.Antialiasing)

    #
    # 函数：实现无标题栏窗口拖动
    #
    def mousePressEvent(self, event):
        if (event.button() == Qt.LeftButton):
            self.mouse_press = True
            self.drag_pos = event.globalPos() - self.pos()
            event.accept()

    def mouseReleaseEvent(self, event):
        self.mouse_press = False
        self.setWindowOpacity(1)

    # def mouseMoveEvent(self, event):
    #     if (self.mouse_press):
    #         self.move_pos = event.globalPos()
    #         self.move(self.move_pos - self.drag_pos)
    #         self.setWindowOpacity(1)
    #         event.accept()




#!/usr/bin/python3
# -*- coding: utf-8 -*-

from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5 import QtCore, QtGui, QtWidgets
from ui.MainWindow import *
from ui.messagebox import *
from ui.download_ranking_card import *
import os
import fcntl
from PyQt5.QtNetwork import QLocalServer,QLocalSocket
import dbus
import sys
import signal
from models.globals import Globals
import logging
#LOG = logging.getLogger(__name__)

import gettext
gettext.textdomain("kylin-software-center")
_ = gettext.gettext
try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

#
#函数名：单例
#
#
pidfile=0
def app_instance():

    serverName = "kylinsoftwarecenter"
    socket = QLocalSocket()
    socket.connectToServer(serverName)
    if socket.waitForConnected(500):
        try:
            for i in os.popen("wmctrl -l |grep " + _("Software Store")):
                wm = i.split()
                if (_("Software Store") in wm):
                    os.system("wmctrl -i -R " + wm[0])
        except:
            pass
        if (Globals.DEBUG_SWITCH):
            print('Software Store has been started.')
        sys.exit(0)
    global  localserver
    localserver = QLocalServer()
    localserver.listen(serverName)
    Globals.LOCAL_SERVER = localserver
    global pidfile
    homePath = QStandardPaths.standardLocations(QStandardPaths.HomeLocation)
    pidfile = open(str(homePath[0]+ "/.config/kylin-software-center%1.lock").replace("%1",os.getenv("DISPLAY")),"w+")
    Globals.PIDFILE = pidfile
    try:
        fcntl.flock(pidfile, fcntl.LOCK_EX | fcntl.LOCK_NB)
    except:
        try:
            for i in os.popen("wmctrl -l |grep " + _("Software Store")):
                wm = i.split()
                if (_("Software Store") in wm):
                    os.system("wmctrl -i -R " + wm[0])
        except:
            pass
        # app.setActiveWindow()
        if (Globals.DEBUG_SWITCH):
            print('Software Store has been started.')
        sys.exit(0)

#
#函数名: 本地包文件
#Function: local debfile
#
def check_local_deb_file(url):
    return os.path.isfile(url)

#
#函数名: 退出
#Function: quit
#
def quit(signum, frame):
    if (Globals.DEBUG_SWITCH):
        print('You choose to stop software-center.')

    # 尝试解锁
    if (Globals.DEBUG_SWITCH):
        Globals.LOG_INFO.logger.info("unlock the file lock.")
    pidfile = Globals.PIDFILE
    try:
        fcntl.flock(pidfile, fcntl.LOCK_UN | fcntl.LOCK_NB)
    except Exception as e:
        Globals.LOG_ERROR.logger.error("unlock the file lock failed : %s" % str(e))
        
    sys.exit()

#
#函数名: 主函数
#Function: main function
#
def main():
    # print("----start-----",datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f"))
    #app = QApplication(sys.argv)
    app_instance()
    try:
        conf = configparser.ConfigParser()
        conf.read(CONF_PATH)
        SHA_TZ = datetime.timezone(datetime.timedelta(hours=8), name='Asia/Shanghai', )
        # 协调世界时
        utc_now = datetime.datetime.utcnow().replace(tzinfo=datetime.timezone.utc)
        beijing_now = utc_now.astimezone(SHA_TZ)
        now_time = str(beijing_now).split(".")[0]
        startup_clients_time = conf.set("essential-information", "start_client_time",now_time)
        with open(CONF_PATH, "w+") as f:
            conf.write(f)
    except:
        pass
    try:
        cmd = "dpkg -l |grep libqt5gui |awk '{print $3}'"
        version = os.popen(cmd).readline().strip("\n")
        if version.startswith("5.6"):
            if ("~" in version):
                if ("k" in version.split("~")[1]):
                    if (int(version.split("~")[1].split("k")[1]) >= 4):
                        QCoreApplication.setAttribute(Qt.AA_EnableHighDpiScaling)
                        QCoreApplication.setAttribute(Qt.AA_UseHighDpiPixmaps)
        else:
            QCoreApplication.setAttribute(Qt.AA_EnableHighDpiScaling)
            QCoreApplication.setAttribute(Qt.AA_UseHighDpiPixmaps)
    except:
        QCoreApplication.setAttribute(Qt.AA_EnableHighDpiScaling)
        QCoreApplication.setAttribute(Qt.AA_UseHighDpiPixmaps)
    app = QApplication(sys.argv)

    app.setStyle("ukui")
    app.setWindowIcon(QIcon.fromTheme("kylin-sotfware-center"))
#   #QTextCodec.setCodecForTr(QTextCodec.codecForName("UTF-8"))
#   #QTextCodec.setCodecForCStrings(QTextCodec.codecForName("UTF-8"))

    globalfont = QFont()
    # globalfont.setFamily("")
    # 文泉驿微米黑
    # 文泉驿等宽微米黑
    # 方正书宋_GBK
    # 方正仿宋_GBK
    # 方正姚体_GBK
    # 方正宋体S-超大字符集
    # 方正宋体S-超大字符集(SIP)
    # 方正小标宋_GBK
    # 方正楷体_GBK
    # 方正细黑一_GBK
    # 方正行楷_GBK
    # 方正超粗黑_GBK
    # 方正隶书_GBK
    # 方正魏碑_GBK
    # 方正黑体_GBK
    globalfont.setPointSize(11)
    app.setFont(globalfont)

    trans = QTranslator()
    trans.load('po/qt_zh_CN.qm')
    QApplication.installTranslator(trans)
    trans2 = QTranslator()
    trans2.load('po/widgets_zh_CN.qm')
    QApplication.installTranslator(trans2)

    # check show quiet
    argn = len(sys.argv)
    if(argn == 1):
        Globals.LAUNCH_MODE = 'normal'
    elif(argn > 1):
        arg = sys.argv[1]
        if(arg == '-quiet'):
            Globals.LAUNCH_MODE = 'quiet'
        elif(arg == '-remove'):
            if(sys.argv[2]):
                Globals.LAUNCH_MODE = 'normal'
                Globals.REMOVE_SOFT = sys.argv[2]
            else:
                if (Globals.LOCAL_SERVER != None):
                    localserver = Globals.LOCAL_SERVER
                    localserver.close()
                sys.exit(0)
        elif(arg == '-find'):
            if (sys.argv[2]):
                Globals.SEARCH_SOFTWARE = sys.argv[2]
            else:
                if (Globals.LOCAL_SERVER != None):
                    localserver = Globals.LOCAL_SERVER
                    localserver.close()
                sys.exit(0)
        else:
            Globals.LAUNCH_MODE = 'normal'
            if(check_local_deb_file(arg)):
                Globals.LOCAL_DEB_FILE = arg
                '''MessageBox = File_window()
                MessageBox.setText(_("Opening files is not supported"))
                MessageBox.exec()'''
                if (Globals.LOCAL_SERVER != None):
                    localserver = Globals.LOCAL_SERVER
                    localserver.close()
                sys.exit(0)
            else:
                if (Globals.LOCAL_SERVER != None):
                    localserver = Globals.LOCAL_SERVER
                    localserver.close()
                sys.exit(0)
    # app_instance()
    # app.setStyle("ukui")
    # print("init_mw", datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f"))
    mw = MainWindow()
    # print("init_mw_over", datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f"))
    # app.desktop().resized.connect(mw.show_new_widget)
    windowWidth = QApplication.desktop().screenGeometry(0).width()
    qScreen = QApplication.primaryScreen()
    qScreen.availableGeometryChanged.connect(mw.show_new_widget)
    windowHeight = QApplication.desktop().screenGeometry(0).height()
    mw.move(int((windowWidth - mw.width()) / 2), int((windowHeight - mw.height()) / 2))
    # app.setStyle("ukui")

    sys.exit(app.exec_())
    os.system("pause")

if __name__ == '__main__':
    main()



#!/usr/bin/python3
# -*- coding: utf-8 -*-

import sys
# reload(sys)
# sys.setdefaultencoding('utf8')
#from gevent import monkey;monkey.patch_all()
from PyQt5.QtCore import QThread
from PyQt5.QtCore import pyqtSignal
import locale
from service.appmanager import *
from service.dbus_service import *
import time
from models.enums import KYDROID_DOWNLOAD_PATH
import threading
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class  init_dbus_Thread(QThread):
    dbus_work_list = []
    dbus_init_over = pyqtSignal(bool)
    get_dbus_workitem_over = pyqtSignal(int)
    def __init__(self,mw):
        super(init_dbus_Thread, self).__init__()
        self.mw = mw
        self.backend = Dbus_Service(True)
        self.get_dbus_workitem_over.connect(self.mw.slot_get_dbus_workitem_over)
        self.backend.check_apt_lock_finish.connect(self.mw.slot_check_apt_lock_finish)
        # self.dbus_init_over.connect(self.mw.slot_init_dbus_over)
        # res = self.backend.init_dbus_ifaces()
        # self.dbus_init_over.emit(res)
        # self.backend.copy_finish.connect(self.mw.slot_copy_file_finish)
        # self.backend.dbus_apt_process.connect(self.mw.slot_dbus_apt_process)
        # self.mutex = threading.RLock()

    def run(self):
        # init dbus backend
        #初始化dbus后台
        self.dbus_init_over.connect(self.mw.slot_init_dbus_over)
        res = self.backend.init_dbus_ifaces()
        self.dbus_init_over.emit(res)
        self.backend.copy_finish.connect(self.mw.slot_copy_file_finish)
        self.backend.dbus_apt_process.connect(self.mw.slot_dbus_apt_process)
        self.mutex = threading.RLock()
        # if (os.path.exists(KYDROID_DOWNLOAD_PATH)):
        #     if (os.path.isdir(KYDROID_DOWNLOAD_PATH)):
        #         pass
        #     else:
        #         action = {"action": "mkdir_kydroid_download_path","path":KYDROID_DOWNLOAD_PATH}
        #         self.mutex.acquire()
        #         self.dbus_work_list.append(action)
        #         self.mutex.release()
        # else:
        #     action = {"action": "mkdir_kydroid_download_path", "path": KYDROID_DOWNLOAD_PATH}
        #     self.mutex.acquire()
        #     self.dbus_work_list.append(action)
        #     self.mutex.release()
        while(True):
            if len(self.dbus_work_list) == 0:
                time.sleep(0.2)
                continue
            self.mutex.acquire()
            item = self.dbus_work_list.pop(0)
            self.mutex.release()
            if (item["action"] == "install"):
                self.backend.install_package(item["appname"])
            # elif(item["action"] == "mkdir_kydroid_download_path"):
            #     self.backend.mk_dir(item["path"])
            elif (item["action"] == "remove"):
                self.backend.remove_package(item["appname"])
            elif (item["action"] == "raising rights"):
                self.backend.call_auth_with_policykit(item["appname"],item["action_id"])
            elif (item["action"] == "clear_dbus_worklist"):
                self.backend.clear_dbus_worklist()
            elif (item["action"] == "check_work_item"):
                res = self.backend.check_dbus_workitem()
                self.get_dbus_workitem_over.emit(res[0])
            elif(item["action"] == "check_apt_lock"):
                self.backend.call_check_apt_lock(item["appname"],item["app_action"],item["percent"])
            elif (item["action"] == "install_apk"):
                self.mw.at.appmgr.start_download_apk(item["app"])
            elif (item["action"] == 'run'):
                self.backend.run_app(item["cmd"])
            time.sleep(0.2)



#!/usr/bin/python3
# -*- coding: utf-8 -*-

### BEGIN LICENSE

# Copyright (C) 2013 National University of Defense Technology(NUDT) & Kylin Ltd

# Author:
#     Shine Huang<shenghuang@ubuntukylin.com>
# Maintainer:
#     Shine Huang<shenghuang@ubuntukylin.com>

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from PyQt5.QtWidgets import *
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from models.enums import UBUNTUKYLIN_RES_PATH
from models.globals import Globals

class MessageBox(QObject):
    # alert
    alert = ''
    # alert timer
    alertTimer = ''
    # alert alive timer
    alertDelayTimer = ''
    # opacity effect
    alertGOE = ''
    # opacity
    ao = ''
    # alert y
    ay = ''

    def __init__(self, parent=None):
        QObject.__init__(self, parent)
        self.alertTimer = QTimer(self)
        self.alertTimer.timeout.connect(self.slot_alert_step)
        self.alertDelayTimer = QTimer(self)
        self.alertDelayTimer.timeout.connect(self.slot_hide_alert)
        self.alertGOE = QGraphicsOpacityEffect()
        self.statu = "success"

        self.alert = QPushButton(parent)
        self.alert.setGeometry(Globals.MAIN_WIDTH / 2 - 203 / 2, Globals.MAIN_HEIGHT / 2 - 56 / 2, 203, 56)
        self.alert.setFocusPolicy(Qt.NoFocus)
        self.alert.setGraphicsEffect(self.alertGOE)
        self.alert.setStyleSheet("QPushButton{background-image:url('" + UBUNTUKYLIN_RES_PATH + "alert.png');border:0px;padding-bottom:4px;color:white;font-size:16px;}")
        self.alert.clicked.connect(self.alert.hide)
        self.alert.hide()

    #
    #函数名: 卸载 
    #Function: remove
    #
    def re_move(self):
        self.alert.setGeometry(Globals.MAIN_WIDTH / 2 - 203 / 2, Globals.MAIN_HEIGHT / 2 - 56 / 2, 203, 56)

    #
    #函数名:警告 
    #Function: alert
    #
    def alert_msg(self, alertText, statu = "success"):
        self.statu = statu
        self.alertTimer.stop()
        self.alertDelayTimer.stop()
        self.ay = 410
        self.ao = 0.0
        self.alertGOE.setOpacity(self.ao)
        self.alert.setText(alertText)
        self.alert.raise_()
        self.alert.show()
        self.alertTimer.start(10)
    #
    #函数名:警告步骤 
    #Function: alert step
    #
    def slot_alert_step(self):
        if(self.ao < 1):
            self.ao += 0.015
            self.alertGOE.setOpacity(self.ao)
        if(self.ay <= 280):
            self.alertTimer.stop()
            # close after * second
            if self.statu == "success":
                self.alertDelayTimer.start(4000)
            else:
                self.alertDelayTimer.stop()
        else:
            self.ay -= 2
            self.alert.move(self.alert.x(), self.ay)

    #
    #函数名:隐藏警告 
    #Function: hide alert
    #
    def slot_hide_alert(self):
        self.alert.hide()
        self.alertDelayTimer.stop()



#!/usr/bin/python3
# -*- coding: utf-8 -*-

### BEGIN LICENSE

# Copyright (C) 2013 National University of Defense Technology(NUDT) & Kylin Ltd

# Author:
#     Shine Huang<shenghuang@ubuntukylin.com>
# Maintainer:
#     Shine Huang<shenghuang@ubuntukylin.com>

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

import dbus
import sys
import signal
import os
import logging
import dbus.service
from gi.repository import GObject
from dbus.mainloop.glib import DBusGMainLoop
mainloop = DBusGMainLoop(set_as_default=True)
LOG = logging.getLogger(__name__)

class UtilDbus(dbus.service.Object):

    def __init__(self, parent, bus_name,
                 object_path='/com/kylin/softwarecenter'):
        dbus.service.Object.__init__(self, bus_name, object_path)
        self.parent = parent

    def stop(self):
        """ stop the dbus controller and remove from the bus """
        self.remove_from_connection()

    @dbus.service.method('com.kylin.utiliface',in_signature='s',out_signature='b')
    def show_search_result(self,appname):
        res = self.parent.click_search_app(appname)
        return res
        #带参数启动软件商店(1.没有启动软件商店则启动软件商店，并且显示到软件详情界面。2.启动了软件商店显示结果的详情界面)

if __name__ == '__main__':
    try:
        bus = dbus.SessionBus(mainloop)
    except:
        sys.exit(0)
    bus_name = dbus.service.BusName('com.kylin.softwarecenter', bus)
    dbusControler = UtilDbus(None,bus_name)


#!/usr/bin/python3
# -*- coding: utf-8 -*-


from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from models.globals import *
from models.apkinfo import *
from models.application import *
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext

class show_ratings_widget(QWidget):
    change_background_image = pyqtSignal()
    submit_my_rating_apk = pyqtSignal(int,ApkInfo)
    submit_my_rating_app = pyqtSignal(int,Application)
    def __init__(self,app_detail,parent):
        QWidget.__init__(self, parent)
        self.m_parent = parent
        self.app_detail = app_detail
        self.MY_SCORE = 0
        self.app_name = ""
        self.pre_app_name = ""
        self.star_list = []
        self.is_click = False
        self.init_ui()
        self.submit_my_rating_apk.connect(self.app_detail.m_parent.mw.slot_submit_my_rating)
        self.submit_my_rating_app.connect(self.app_detail.m_parent.mw.slot_submit_my_rating)
        self.timer = QTimer(self)
        self.timer.timeout.connect(self.slot_timer_timeout)

    def init_ui(self):
        self.count_of_participation_rating = QLabel(self)
        self.count_of_participation_rating.resize(96, 20)
        self.count_of_participation_rating.move(0,0)
        self.count_of_participation_rating.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
        self.label1 = start_label(self)
        self.label1.move(0, self.count_of_participation_rating.y()+self.count_of_participation_rating.height()+15)
        self.label2 = start_label(self)
        self.label2.move(7+self.label1.x()+self.label1.width(), self.label1.y())
        self.label3 = start_label(self)
        self.label3.move(7+self.label2.x()+self.label2.width(), self.label1.y())
        self.label4 = start_label(self)
        self.label4.move(7+self.label3.x()+self.label3.width(), self.label1.y())
        self.label5 = start_label(self)
        self.label5.move(7+self.label4.x()+self.label4.width(), self.label1.y())
        self.process1 = QProgressBar(self)
        self.process1.setMinimum(0)
        self.process1.setMaximum(100)
        self.process1.setTextVisible(False)
        self.process1.resize(240,8)
        self.process1.move(self.label5.x()+self.label5.width()+22,self.label1.y() + int((self.label1.height()-self.process1.height())/2))
        self.label6 = start_label(self)
        self.label6.move(self.label2.x(), self.label2.height()+self.label2.y()+5)
        self.label7 = start_label(self)
        self.label7.move(self.label3.x(), self.label2.height()+self.label2.y()+5)
        self.label8 = start_label(self)
        self.label8.move(self.label4.x(), self.label2.height()+self.label2.y()+5)
        self.label9 = start_label(self)
        self.label9.move(self.label5.x(), self.label2.height()+self.label2.y()+5)
        self.process2 = QProgressBar(self)
        self.process2.setMinimum(0)
        self.process2.setMaximum(100)
        self.process2.setTextVisible(False)
        self.process2.resize(240,8)
        self.process2.move(self.label9.x()+self.label9.width()+22,self.label9.y() + int((self.label9.height()-self.process2.height())/2))
        self.label10 = start_label(self)
        self.label10.move(self.label3.x(), self.label6.height()+self.label6.y()+5)
        self.label11 = start_label(self)
        self.label11.move(self.label4.x(), self.label6.height()+self.label6.y()+5)
        self.label12 = start_label(self)
        self.label12.move(self.label5.x(), self.label6.height()+self.label6.y()+5)
        self.process3 = QProgressBar(self)
        self.process3.setMinimum(0)
        self.process3.setMaximum(100)
        self.process3.setTextVisible(False)
        self.process3.resize(240,8)
        self.process3.move(self.label12.x()+self.label12.width()+22,self.label10.y() + int((self.label10.height()-self.process3.height())/2))
        self.label13 = start_label(self)
        self.label13.move(self.label4.x(), self.label10.height()+self.label10.y()+5)
        self.label14 = start_label(self)
        self.label14.move(self.label5.x(), self.label10.height()+self.label10.y()+5)
        self.process4 = QProgressBar(self)
        self.process4.setMinimum(0)
        self.process4.setMaximum(100)
        self.process4.setTextVisible(False)
        self.process4.resize(240,8)
        self.process4.move(self.label14.x()+self.label14.width()+22,self.label14.y() + int((self.label14.height()-self.process4.height())/2))
        self.label15 = start_label(self)
        self.label15.move(self.label5.x(), self.label13.height()+self.label13.y()+5)
        self.process5 = QProgressBar(self)
        self.process5.setMinimum(0)
        self.process5.setMaximum(100)
        self.process5.setTextVisible(False)
        self.process5.resize(240,8)
        self.process5.move(self.label15.x()+self.label15.width()+22,self.label15.y() + int((self.label15.height()-self.process5.height())/2))

        self.my_ratings = QLabel(self)
        self.my_ratings.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
        self.my_ratings.setText(_("My ratings"))
        self.my_ratings.adjustSize()
        self.my_ratings.move(self.process1.x()+self.process1.width(),self.count_of_participation_rating.y())

        self.set_progressbar_color()
        self.clear_progress()

        self.star1 = start_btn(1,"big",self)
        self.star1.move(self.my_ratings.x(),self.my_ratings.y()+self.my_ratings.height()+28)
        self.star_list.append(self.star1)
        self.star2 = start_btn(2,"big",self)
        self.star2.move(self.star1.x()+self.star1.width()+9,self.my_ratings.y()+self.my_ratings.height()+28)
        self.star_list.append(self.star2)
        self.star3 = start_btn(3,"big",self)
        self.star3.move(self.star2.x()+self.star2.width()+9,self.my_ratings.y()+self.my_ratings.height()+28)
        self.star_list.append(self.star3)
        self.star4 = start_btn(4,"big",self)
        self.star4.move(self.star3.x()+self.star3.width()+9,self.my_ratings.y()+self.my_ratings.height()+28)
        self.star_list.append(self.star4)
        self.star5 = start_btn(5,"big",self)
        self.star5.move(self.star4.x()+self.star4.width()+9,self.my_ratings.y()+self.my_ratings.height()+28)
        self.star_list.append(self.star5)

        self.edit_btn = QPushButton(self)
        self.edit_btn.setFocusPolicy(Qt.NoFocus)
        self.edit_btn.setAttribute(Qt.WA_TranslucentBackground)
        self.edit_btn.setStyleSheet("QPushButton{background-color:transparent;border:0px;}QPushButton:hover{background-color:transparent;border:0px;}QPushButton:pressed{background-color:transparent;border:0px;}")

        self.edit_pen = QLabel(self.edit_btn)
        self.edit_pen.setFocusPolicy(Qt.NoFocus)
        self.edit_pen.setFixedSize(20,20)
        self.edit_pen.setStyleSheet("QLabel{background-image:url(./res/edit.png);}")
        self.edit_pen.move(0,0)

        self.edit_label = QLabel(self.edit_btn)
        self.edit_label.resize(80,26)
        self.edit_label.setFocusPolicy(Qt.NoFocus)
        self.edit_label.setText(_("Write comments"))
        self.edit_label.setStyleSheet("QLabel{font-size: 18px;font-weight: 500;color: #3790FA;line-height: 26px;}")
        self.edit_label.adjustSize()

        self.edit_btn.resize(self.edit_pen.width()+self.edit_label.width(),self.edit_label.height())
        self.edit_label.move(self.edit_btn.width()-self.edit_label.width(),0)
        self.edit_pen.move(0, int((self.edit_label.height()-self.edit_pen.height())/2))
        self.edit_btn.move(self.star5.x()+self.star5.width()-self.edit_btn.width(),int((self.my_ratings.height()-self.edit_btn.height())/2))

        self.btn_all_review = QPushButton(self)
        self.btn_all_review.setText(_("View reviews"))
        self.btn_all_review.setFocusPolicy(Qt.NoFocus)
        self.btn_all_review.setStyleSheet(
            "QPushButton{background: transparent;border:none;font-size: 18px;font-weight: 400;text-align: left;color: #3790FA;line-height: 12px;}")
        # self.btn_all_review.resize(120,40)
        if Globals.LAN == 'zh_CN':
            self.btn_all_review.setFixedSize(len(self.btn_all_review.text()) * 18, 20)
        else:
            self.btn_all_review.setFixedSize(len(self.btn_all_review.text()) * 9, 20)
        self.btn_all_review.adjustSize()
        self.btn_all_review.move(self.star5.x()+self.star5.width()-self.btn_all_review.width(),self.star1.y()+self.star1.height()+30)


        self.setFixedHeight(self.label15.y()+self.label15.height()+10)

    def resize_progress(self,size):
        if(self.process1.width() - size < 130):
            self.process1.resize(130,self.process1.height())
            self.process2.resize(130,self.process1.height())
            self.process3.resize(130,self.process1.height())
            self.process4.resize(130,self.process1.height())
            self.process5.resize(130,self.process1.height())
            self.my_ratings.move(self.my_ratings.x()-(size - 100),
                                 self.count_of_participation_rating.y())
            self.star1.move(self.my_ratings.x(), self.my_ratings.y() + self.my_ratings.height() + 28)
            self.star2.move(self.star1.x() + self.star1.width() + 9,
                            self.my_ratings.y() + self.my_ratings.height() + 28)
            self.star3.move(self.star2.x() + self.star2.width() + 9,
                            self.my_ratings.y() + self.my_ratings.height() + 28)
            self.star4.move(self.star3.x() + self.star3.width() + 9,
                            self.my_ratings.y() + self.my_ratings.height() + 28)
            self.star5.move(self.star4.x() + self.star4.width() + 9,
                            self.my_ratings.y() + self.my_ratings.height() + 28)
        else:
            self.process1.resize(self.process1.width() - size, self.process1.height())
            self.process2.resize(self.process2.width() - size, self.process1.height())
            self.process3.resize(self.process3.width() - size, self.process1.height())
            self.process4.resize(self.process4.width() - size, self.process1.height())
            self.process5.resize(self.process5.width() - size, self.process1.height())

    def reload_progress(self):
        self.process1.resize(240, self.process1.height())
        self.process2.resize(240, self.process1.height())
        self.process3.resize(240, self.process1.height())
        self.process4.resize(240, self.process1.height())
        self.process5.resize(240, self.process1.height())

    def re_move(self,need_move_space,proportion):
        self.setFixedWidth(self.width()+need_move_space)
        self.my_ratings.move(self.process1.x() + self.process1.width() + need_move_space,
                             self.count_of_participation_rating.y())
        self.star1.move(self.my_ratings.x(), self.my_ratings.y() + self.my_ratings.height() + 28)
        self.star2.move(self.star1.x() + self.star1.width() + 9, self.my_ratings.y() + self.my_ratings.height() + 28)
        self.star3.move(self.star2.x() + self.star2.width() + 9, self.my_ratings.y() + self.my_ratings.height() + 28)
        self.star4.move(self.star3.x() + self.star3.width() + 9, self.my_ratings.y() + self.my_ratings.height() + 28)
        self.star5.move(self.star4.x() + self.star4.width() + 9, self.my_ratings.y() + self.my_ratings.height() + 28)
        self.edit_btn.move(self.star5.x() + self.star5.width() - self.edit_btn.width(), 0)
        self.btn_all_review.move(self.star5.x() + self.star5.width() - self.btn_all_review.width(),
                                 self.star1.y() + self.star1.height() + 30)
        # self.resize()

    def clear_progress(self):
        self.process1.hide()
        self.process1.setValue(0)
        self.process1.show()
        self.process2.hide()
        self.process2.setValue(0)
        self.process2.show()
        self.process3.hide()
        self.process3.setValue(0)
        self.process3.show()
        self.process4.hide()
        self.process4.setValue(0)
        self.process4.show()
        self.process5.hide()
        self.process5.setValue(0)
        self.process5.show()

    def slot_enter_star(self,num):
        n = 0
        if(num == -1):
            if (Globals.LOGIN_SUCCESS):
                num = self.MY_SCORE
            else:
                num = 0
        for star in self.star_list:
            if(n < num):
                self.star_list[n].setStyleSheet("QPushButton{background-image: url(./res/my_ratings_star.png);border:0px;}")
            else:
                self.star_list[n].setStyleSheet("QPushButton{background-image: url(./res/my_rating_star2.png);border:0px;}")
            n = n + 1

    def slot_click_star(self,num,need_send = True):
        pre_my_score = self.MY_SCORE
        if (Globals.LOGIN_SUCCESS):
            self.MY_SCORE = num
        else:
            self.MY_SCORE = 0
        #(^-^)
        if(Globals.LOGIN_SUCCESS):
            if(self.app_detail.app_msg.from_ukscdb == True):
                n = 0
                for star in self.star_list:
                    self.star_list[n].mouse_press = True
                    if (n < num):
                        self.star_list[n].setStyleSheet("QPushButton{background-image: url(./res/my_ratings_star.png);border:0px;}")
                    else:
                        self.star_list[n].setStyleSheet("QPushButton{background-image: url(./res/my_rating_star2.png);border:0px;}")
                    n = n + 1
                #发送评分到服务器 num为多少就是几分
                if(need_send == True):
                    if (self.timer.isActive()):
                        if(self.pre_app_name == self.app_name):
                            self.slot_click_star(pre_my_score, False)
                            self.app_detail.m_parent.mw.show_tip_widget(_("The operation is too frequent. Please try again later!"),True)
                            self.app_detail.m_parent.mw.tip_widget.btn.clicked.connect(self.app_detail.m_parent.mw.slot_close_tipwidget)
                            self.change_star_state()
                        else:
                            if (self.app_detail.btn.text() == _("Open") or self.app_detail.btn.text() == _("installed") or self.app_detail.btn.text() == _("update")):
                                if (type(self.app_detail.app_msg) == ApkInfo):
                                    self.submit_my_rating_apk.emit(num, self.app_detail.app_msg)
                                else:
                                    self.submit_my_rating_app.emit(num, self.app_detail.app_msg)
                                self.timer.start(10000)
                                self.pre_app_name = self.app_name
                            else:
                                # self.refresh_star()
                                self.slot_click_star(self.MY_SCORE, False)
                                self.app_detail.m_parent.mw.show_tip_widget(_("Please install the software before scoring!"), True)
                                self.app_detail.m_parent.mw.tip_widget.btn.clicked.connect(
                                    self.app_detail.m_parent.mw.slot_close_tipwidget)
                                self.change_star_state()
                    else:
                        if(self.app_detail.btn.text() == _("Open") or self.app_detail.btn.text() == _("installed") or self.app_detail.btn.text() == _("update")):
                            if(type(self.app_detail.app_msg) == ApkInfo):
                                self.submit_my_rating_apk.emit(num,self.app_detail.app_msg)
                            else:
                                self.submit_my_rating_app.emit(num, self.app_detail.app_msg)
                            self.timer.start(10000)
                            self.pre_app_name = self.app_name
                        else:
                            # self.refresh_star()
                            self.slot_click_star(pre_my_score, False)
                            # self.slot_click_star(self.MY_SCORE,False)
                            self.app_detail.m_parent.mw.show_tip_widget(_("Please install the software before scoring!"), True)
                            self.app_detail.m_parent.mw.tip_widget.btn.clicked.connect(self.app_detail.m_parent.mw.slot_close_tipwidget)
                            self.change_star_state()
            else:
                if(need_send == True):
                    n = 0
                    for star in self.star_list:
                        self.star_list[n].setStyleSheet("QPushButton{background-image: url(./res/my_rating_star2.png);border:0px;}")
                        n = n + 1
                    self.app_detail.m_parent.mw.show_tip_widget(_("Non database software, does not support scoring!"),True)
                    self.app_detail.m_parent.mw.tip_widget.btn.clicked.connect(self.app_detail.m_parent.mw.slot_close_tipwidget)
                    self.change_star_state()
                else:
                    self.refresh_star()
                    self.change_star_state()
        else:
            self.refresh_star()
            self.app_detail.m_parent.mw.show_tip_widget(_("Please log in before scoring!"))
            self.app_detail.m_parent.mw.tip_widget.btn.clicked.connect(self.app_detail.m_parent.mw.slot_close_tipwidget)
            self.change_star_state()

    #
    #函数：刷新星星
    #
    def refresh_star(self):
        n = 0
        for star in self.star_list:
            self.star_list[n].setStyleSheet("QPushButton{background-image: url(./res/my_rating_star2.png);border:0px;}")
            n = n + 1

    def change_star_state(self):
        n = 0
        for star in self.star_list:
            self.star_list[n].mouse_press = False
            n = n + 1

    def set_progressbar_color(self):
        self.change_background_image.emit()
        re = os.popen("lscpu |grep -i 3A3000").readlines()
        if(re):
            if (Globals.THEME_COLOR == 0):
                self.process1.setStyleSheet(
                    "QProgressBar{background-color:#C0C4CC;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}")
                self.process2.setStyleSheet(
                    "QProgressBar{background-color:#C0C4CC;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}")
                self.process3.setStyleSheet(
                    "QProgressBar{background-color:#C0C4CC;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}")
                self.process4.setStyleSheet(
                    "QProgressBar{background-color:#C0C4CC;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}")
                self.process5.setStyleSheet(
                    "QProgressBar{background-color:#C0C4CC;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}")
                self.my_ratings.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
                self.count_of_participation_rating.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
            else:
                self.process1.setStyleSheet(
                    "QProgressBar{background-color:#3D3D41;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}")
                self.process2.setStyleSheet(
                    "QProgressBar{background-color:#3D3D41;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}")
                self.process3.setStyleSheet(
                    "QProgressBar{background-color:#3D3D41;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}")
                self.process4.setStyleSheet(
                    "QProgressBar{background-color:#3D3D41;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}")
                self.process5.setStyleSheet(
                    "QProgressBar{background-color:#3D3D41;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}")
                self.my_ratings.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #F9F9F9;line-height: 20px;}")
                self.count_of_participation_rating.setStyleSheet(
                    "QLabel{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 20px;}")
        else:
            if (Globals.THEME_COLOR == 0):
                self.process1.setStyleSheet(
                    "QProgressBar{background-color:#C0C4CC;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}"
                    "QProgressBar:chunk{background-color:#606265;border-radius:4px;}")
                self.process2.setStyleSheet(
                    "QProgressBar{background-color:#C0C4CC;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}"
                    "QProgressBar:chunk{background-color:#606265;border-radius:4px;}")
                self.process3.setStyleSheet(
                    "QProgressBar{background-color:#C0C4CC;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}"
                    "QProgressBar:chunk{background-color:#606265;border-radius:4px;}")
                self.process4.setStyleSheet(
                    "QProgressBar{background-color:#C0C4CC;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}"
                    "QProgressBar:chunk{background-color:#606265;border-radius:4px;}")
                self.process5.setStyleSheet(
                    "QProgressBar{background-color:#C0C4CC;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}"
                    "QProgressBar:chunk{background-color:#606265;border-radius:4px;}")
                self.my_ratings.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
                self.count_of_participation_rating.setStyleSheet(
                    "QLabel{font-size: 14px;font-weight: 400;color: #606265;line-height: 20px;}")
            else:
                self.process1.setStyleSheet(
                    "QProgressBar{background-color:#3D3D41;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}"
                    "QProgressBar:chunk{background-color:#8F9399;border-radius:4px;}")
                self.process2.setStyleSheet(
                    "QProgressBar{background-color:#3D3D41;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}"
                    "QProgressBar:chunk{background-color:#8F9399;border-radius:4px;}")
                self.process3.setStyleSheet(
                    "QProgressBar{background-color:#3D3D41;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}"
                    "QProgressBar:chunk{background-color:#8F9399;border-radius:4px;}")
                self.process4.setStyleSheet(
                    "QProgressBar{background-color:#3D3D41;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}"
                    "QProgressBar:chunk{background-color:#8F9399;border-radius:4px;}")
                self.process5.setStyleSheet(
                    "QProgressBar{background-color:#3D3D41;border:0px solid #aaaaaa;border-radius:4px;color:#666666;text-align:center;}"
                    "QProgressBar:chunk{background-color:#8F9399;border-radius:4px;}")
                self.my_ratings.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #F9F9F9;line-height: 20px;}")
                self.count_of_participation_rating.setStyleSheet(
                    "QLabel{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 20px;}")

    #
    #函数：处理计时器超时
    #
    def slot_timer_timeout(self):
        self.timer.stop()
        self.pre_app_name = ""


class start_label(QLabel):
    def __init__(self,parent):
        QLabel.__init__(self, parent)
        self.m_parent = parent
        self.resize(19,19)
        self.init_ui()
        self.m_parent.change_background_image.connect(self.init_ui)

    def init_ui(self):
        if(Globals.THEME_COLOR == 0):
            self.setStyleSheet("QLabel{background-image: url(./res/S.png);background-color:transparent;}")
        else:
            self.setStyleSheet("QLabel{background-image: url(./res/s_dark.png);background-color:transparent;}")


class start_btn(QPushButton):
    enter_btn = pyqtSignal(int)
    click_btn = pyqtSignal(int)
    def __init__(self,num,size,parent):
        QPushButton.__init__(self,parent)
        self.m_parent = parent
        self.mouse_press = False
        self.num = num
        self.size = size
        self.setFocusPolicy(Qt.NoFocus)
        if(self.size == "big"):
            self.resize(42,42)
            self.setStyleSheet("QPushButton{background-image: url(./res/my_rating_star2.png);border:0px;}QPushButton:hover{background-image: url(./res/my_ratings_star.png);}QPushButton:pressed{background-image: url(./res/my_ratings_star2.png);}")
        else:
            self.resize(30, 30)
            self.setStyleSheet(
                "QPushButton{background-image: url(./res/medium_dark_star.png);border:0px;}QPushButton:hover{background-image: url(./res/medium_bright_star.png);}QPushButton:pressed{background-image: url(./res/medium_bright_star.png);}")
        self.enter_btn.connect(self.m_parent.slot_enter_star)
        self.click_btn.connect(self.m_parent.slot_click_star)

    #
    # 函数：鼠标进入事件
    #
    def enterEvent(self,event):
        if (self.mouse_press == False):
            self.enter_btn.emit(self.num)
        self.update()

    #
    # 函数：鼠标按下事件
    #
    def mousePressEvent(self,event):
        if(event.button() == Qt.LeftButton):
            if(self.mouse_press == False):
                self.mouse_press = True
                if((self.m_parent.app_detail.btn.text() == _("Open") or self.m_parent.app_detail.btn.text() == _("installed") or self.m_parent.app_detail.btn.text() == _("update"))
                        and not (self.m_parent.timer.isActive() and self.m_parent.pre_app_name == self.m_parent.app_name)):
                    self.click_btn.emit(self.num)
                else:
                    self.click_btn.emit(self.m_parent.MY_SCORE)
            self.update()

    #
    # 函数：鼠标释放事件
    #
    def mouseReleaseEvent(self,event):
        if(self.mouse_press and self.rect().contains(event.pos())):
            self.mouse_press = True
            self.update()

    #
    # 函数：鼠标离开事件
    #
    def leaveEvent(self,event):
        if(self.mouse_press == False):
            if(self.size == "big"):
                self.setStyleSheet("QPushButton{background-image: url(./res/my_rating_star2.png);border:0px;}")
            else:
                self.setStyleSheet("QPushButton{background-image: url(./res/medium_dark_star.png);border:0px;}")
            self.enter_btn.emit(-1)
        self.update()



#!/usr/bin/python3
# -*- coding: utf-8 -*-


from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from models.enums import setLongTextToElideFormat,BUTTON_PRESSED,BUTTON_LEAVE,BUTTON_ENTER,AppMsg,PKG_NAME
from models.application import *
from models.apkinfo import *
from utils import commontools
from ui.circular_progress_bar import *
from ui.uninstall_btn import *
import gettext
gettext.bindtextdomain("kylin-software-center", "/usr/share/locale")
gettext.textdomain("kylin-software-center")
_ = gettext.gettext


class Card_Widget(QFrame):
    clicked_card = pyqtSignal(Application)
    clicked_kycard = pyqtSignal(ApkInfo)
    card_width = 357
    card_height = 223
    send_download_progress = pyqtSignal(int)
    puase_download = pyqtSignal(Application)
    puase_apk_download = pyqtSignal(ApkInfo)
    check_all_check_statue = pyqtSignal()

    def __init__(self, width,hight,btn_height,app,mw,detail,ca,parent=None):
        QWidget.__init__(self, parent)
        self.app = app
        self.mw = mw
        self.x_width = width
        self.y_height = hight
        self.pre_progress = 0
        self.detail_widget = detail
        self.down_widget_hight = btn_height
        self.ca = ca
        self.m_parent = parent
        self.font = QFont()
        self.font.setPixelSize(12)
        self.m_font = QFontMetrics(self.font)
        self.narrow_btn_time = QTimer()
        self.narrow_btn_time.timeout.connect(self.move_btn)
        self.init_ui()
        self.clicked_card.connect(self.detail_widget.slot_clicked_card)
        self.clicked_kycard.connect(self.detail_widget.slot_clicked_card)
        self.mw.sigenal_show_downloading_widget.connect(self.show_downloading_widget)
        self.show()

    def init_ui(self):
        self.resize(self.x_width,self.y_height)
        self.setFocusPolicy(Qt.NoFocus)
        self.setWindowFlags(Qt.FramelessWindowHint)
        self.setAttribute(Qt.WA_TranslucentBackground)
        self.setStyleSheet("QFrame{border:0px solid #ff0000;border-radius: 12px;background-color:#999999;}")

        self.icon_widget = QWidget(self)
        self.icon_widget.setAttribute(Qt.WA_TranslucentBackground)
        self.icon_widget.resize(self.width(),self.height()-6)
        self.icon_widget.setStyleSheet("QWidget{border-radius: 12px;}")
        self.icon_widget.move(0,0)

        self.hover_widget = QWidget(self)
        self.hover_widget.resize(self.width(), self.height())
        self.hover_widget.setWindowFlags(Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint)
        # self.card_list_widget.setAttribute(Qt.WA_TranslucentBackground)
        self.hover_widget.setStyleSheet("QWidget{background: rgba(0, 0, 0, 0.1);border-radius: 12px;}")
        self.hover_widget.move(0, 0)
        self.hover_widget.hide()

        self.check_btn = QCheckBox(self.icon_widget)
        self.check_btn.setFixedSize(16,16)
        self.check_btn.setFocusPolicy(Qt.NoFocus)
        self.check_btn.setCheckState(Qt.Unchecked)
        self.check_btn.setStyleSheet(
            "QCheckBox{border-radius: 10px;spacing: 0px;color:#666666;font-size:14px;background-color:#FFFFFF;background-image:url(./res/circular_uncheck.png);}" \
            "QCheckBox:hover{background-color:#DAE3FA;background-image:url(./res/circular_uncheck.png);}" \
            "QCheckBox::indicator{width: 20px;height: 20px;border-radius:10px;}" \
            "QCheckBox::indicator:unchecked{background-color:#FFFFFF;border:1px solid #bfbfbf;}" \
            "QCheckBox::indicator:unchecked:hover{background-color:#DAE3FA;border:1px solid #6B8EEB;}" \
            "QCheckBox::indicator:unchecked:pressed{background-color:#BCCCF6;border:1px solid #415FC4;}" \
            "QCheckBox::indicator{width: 20px;height: 20px;}" \
            "QCheckBox::indicator:checked{background-color:#3D6BE5;border:1px solid #415FC4;image: url(./res/check);}" \
            "QCheckBox::indicator:checked:hover{background-color:#6B8EEB;border:1px solid #415FC4;image: url(./res/check);}" \
            "QCheckBox::indicator:checked:pressed{background-color:#415FC4;border:1px solid #415FC4;image: url(./res/check);}")
        self.check_btn.move(10,10)
        self.check_btn.hide()

        self.icon_label = QLabel(self.icon_widget)
        self.icon_label.resize(self.width(),self.height()-6)
        self.icon_label.move(0,0)
        iconpath = commontools.get_coverimage_path(self.app.pkgname)
        # self.icon_label.setStyleSheet("QLabel{border-radius: 12px;border-image: url('"+iconpath+"') 0 0 0 0 stretch strectch;background-color:transparent;}")
        if(Globals.DEVICE == 1):
            self.icon_label.setStyleSheet("QLabel{border-radius: 12px;background-color:transparent;}")
            self.pix2 = QPixmap(iconpath)
            #图片按照要求提供尺寸修改大小，Qt.IgnoreAspectRatio(忽略图片自身横纵比)
            self.fitpixmap_userIcon = self.pix2.scaled(self.card_width, self.card_height, Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
            self.fitpixmap_userIcon = self.PixmapToRound(self.fitpixmap_userIcon, self.card_width,self.card_height)
            self.icon_label.setPixmap(self.fitpixmap_userIcon)
        else:
            self.icon_label.setStyleSheet("QLabel{border-image:url('" + iconpath + "');border-radius: 12px;}")
        # self.icon_label.setStyleSheet("QLabel{background-image:url('" + iconpath + "');border-radius: 12px;background-repeat: repeat-xy;background-position: center;background-attachment: fixed;background-clip: padding;}")
        self.icon_label.setScaledContents(True)

        self.down_widget = QFrame(self)
        self.down_widget.resize(self.width(), self.down_widget_hight)
        self.down_widget.move(0, self.height()-self.down_widget_hight)
        self.down_widget.setStyleSheet("QFrame{background-color: #F4F4F4;border-bottom-left-radius:12px;border-bottom-right-radius:12px;border-top-left-radius:0px;border-top-right-radius:0px;}")
        self.down_widget.show()

        self.name_label = QLabel(self.down_widget)
        self.name_label.setAttribute(Qt.WA_TranslucentBackground)
        self.name_label.setMaximumWidth(150)
        self.name_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #303133;line-height: 17px;}")
        if(Globals.LAN == "zh_CN"):
            if self.app.displayname_cn != '' and self.app.displayname_cn is not None and self.app.displayname_cn != 'None':
                setLongTextToElideFormat(self.name_label, self.app.displayname_cn)
                # setLongTextToElideFormat(self.ui.named, self.app.displayname_cn)
            else:
                setLongTextToElideFormat(self.name_label, self.app.pkgname)
        else:
            setLongTextToElideFormat(self.name_label, self.app.pkgname)
        self.name_label.adjustSize()
        self.name_label.move(10,int((self.down_widget.height()-self.name_label.height())/2))

        self.line_label = QLabel(self.down_widget)
        self.line_label.setFixedSize(1,17)
        self.line_label.setStyleSheet("QLabel{background-color: #303133;}")
        self.line_label.move(self.name_label.x()+self.name_label.width()+10,int((self.down_widget.height()-self.line_label.height())/2))

        self.category_label = QLabel(self.down_widget)
        self.category_label.setAttribute(Qt.WA_TranslucentBackground)
        self.category_label.resize(28,20)
        self.category_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 17px;}")
        if self.app.category_name_cn != '' and self.app.category_name_cn is not None and self.app.category_name_cn != 'None' and Globals.LAN == "zh_CN":
            self.category_label.setText(self.app.category_name_cn.split("、")[0])
        else:
            self.category_label.setText(self.app.category_name.split("、")[0])
        self.category_label.adjustSize()
        self.category_label.move(self.line_label.width()+self.line_label.x()+4,int((self.down_widget.height()-self.category_label.height())/2))

        self.btn = QPushButton(self.down_widget)
        self.btn.setFocusPolicy(Qt.NoFocus)
        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 12px;border-radius: 12px;border: 0px solid #3790FA;background: #3790FA;}QPushButton:hover{background: #40A9FB;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
        self.btn.resize(52,24)
        self.btn.move(self.down_widget.width()-self.btn.width()-10,int((self.down_widget.height()-self.btn.height())/2))
        self.btn.show()
        self.btn.clicked.connect(lambda: self.mw.slot_click_action_btn(self, self.btn.text(), self.app))

        self.down_progress = Circular_Progress_Bar(22, 22,self.app.pkgname,self.down_widget)
        self.down_progress.update_progress(self.app.percent)
        self.down_progress.move(self.down_widget.width() - self.down_progress.width() - 10,
                                int((self.down_widget.height() - self.down_progress.height()) / 2))
        self.send_download_progress.connect(self.down_progress.GenUpdate)
        self.down_progress.hide()

        self.cancel_btn = QPushButton(self.down_widget)
        self.cancel_btn.setFocusPolicy(Qt.NoFocus)
        self.cancel_btn.resize(22, 22)
        self.cancel_btn.setStyleSheet("QPushButton{background-image:url(./res/cancel1.png);border-radius:11px;}QPushButton:hover{background-image:url(./res/cancel1_hover.png);border-radius:11px;}")
        # self.cancel_btn.resize(48, 22)
        # self.cancel_btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 14px;text-align: center;background: rgba(0, 0, 0, 0.7);border-radius: 11px;}QPushButton:hover{background: #000000;}QPushButton:pressed{background: #000000;}")
        # self.cancel_btn.setText(_("cancel"))
        self.cancel_btn.move(self.down_progress.x() - self.cancel_btn.width() - 8, self.down_progress.y())
        self.cancel_btn.hide()

        self.remove_btn = uninstall_btn(self.down_widget)

        self.remove_btn.move(self.width() - self.remove_btn.width() - 20, int((self.down_widget.height() - self.remove_btn.height())/2))
        self.remove_btn.hide()
        self.cancel_btn.clicked.connect(lambda: self.mw.slot_click_cancel_btn(self, self.app))
        self.down_progress.btn.clicked.connect(self.slot_puase_download)
        self.down_progress.cont_btn.clicked.connect(lambda :self.mw.re_download_app(self.app))
        self.change_btn_state(self.app.pkgname,self.app.status)
        self.slot_set_dark_mode()


    def re_move(self):
        self.hover_widget.resize(self.width(),self.height())
        self.icon_widget.resize(self.width(),self.height())
        self.icon_widget.move(0,0)
        self.icon_label.resize(self.width(), self.height() - 2)
        iconpath = commontools.get_coverimage_path(self.app.pkgname)
        if (Globals.DEVICE == 1):
            self.icon_label.setStyleSheet("QLabel{border-radius: 12px;background-color:transparent;}")
            self.pix2 = QPixmap(iconpath)
            fitpixmap_userIcon = self.pix2.scaled(self.width(), self.height() - 2, Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
            fitpixmap_userIcon = self.PixmapToRound(fitpixmap_userIcon, self.width(), self.height() - 2)
            self.icon_label.setPixmap(fitpixmap_userIcon)
            self.icon_label.setScaledContents(True)
        else:
            self.icon_label.setStyleSheet("QLabel{border-image:url('" + iconpath + "');border-radius: 12px;}")
        # self.icon_label.setStyleSheet(
            # "QLabel{background-image:url('" + iconpath + "');border-radius: 12px;background-repeat: repeat-xy;background-position: center;background-attachment: fixed;background-clip: padding;}")

        self.icon_label.move(0, 0)
        self.down_widget.resize(self.width(), self.down_widget_hight)
        self.down_widget.move(0, self.height() - self.down_widget_hight)
        self.name_label.move(10, int((self.down_widget.height() - self.name_label.height()) / 2))
        self.line_label.move(self.name_label.x() + self.name_label.width() + 10,
                             int((self.down_widget.height() - self.line_label.height()) / 2))
        self.category_label.move(self.line_label.width() + self.line_label.x() + 4,
                                 int((self.down_widget.height() - self.category_label.height()) / 2))
        self.btn.move(self.down_widget.width() - self.btn.width() - 10,
                      int((self.down_widget.height() - self.btn.height()) / 2))
        self.down_progress.move(self.down_widget.width() - self.down_progress.width() - 10,
                                int((self.down_widget.height() - self.down_progress.height()) / 2))
        self.cancel_btn.move(self.down_progress.x() - self.cancel_btn.width() - 8, self.down_progress.y())
        self.remove_btn.move(self.width() - self.remove_btn.width() - 20,
                             int((self.down_widget.height() - self.remove_btn.height()) / 2))

    #将图片绘制为圆角
    def PixmapToRound(self,src,x,y):
        pixmapa = QPixmap(src)
        pixmap = QPixmap(x, y)
        pixmap.fill(Qt.transparent)
        painter = QPainter(pixmap)
        painter.setRenderHint(QPainter.Antialiasing, True)
        painter.setRenderHint(QPainter.TextAntialiasing, True)  #文字尽量抗锯齿
        # painter.setRenderHint(QPainter.SmoothPixmapTransform, True)
        # painter.setRenderHints(QPainter.Antialiasing | QPainter.SmoothPixmapTransform)
        path = QPainterPath()
        rect = QRectF(0,0,x,y)
        path.addRoundedRect(rect, 12.0, 12.0)
        painter.setClipPath(path)
        painter.drawPixmap(0, 0, x, y, pixmapa)

        return pixmap


    #
    #函数：设置按钮的样式
    #
    def set_btn_stylesheet(self,is_uninstall = False):
        if(is_uninstall == True):
            self.btn.setEnabled(True)
            self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;text-align: center;background: rgba(55, 144, 250, 0.08);border-radius: 12px;background:transparent;}QPushButton:hover{background: #F56C6C;;border-radius: 12px;color: #ffffff;}QPushButton:pressed{background: #F56C6C;border-radius: 12px;color: #ffffff;}")

    #
    # 函数：设置深色模式
    #
    def slot_set_dark_mode(self):
        if (Globals.THEME_COLOR == 0):
            self.setStyleSheet("QFrame{border:0px solid #ff0000;border-radius: 12px;background-color:#ffffff;}")
            self.name_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #303133;line-height: 17px;}")
            self.category_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 17px;}")
            self.down_widget.setStyleSheet("QFrame{background-color: #F4F4F4;border-bottom-left-radius:12px;border-bottom-right-radius:12px;border-top-left-radius:0px;border-top-right-radius:0px;}")
            self.line_label.setStyleSheet("QLabel{background-color: #303133;}")
            self.cancel_btn.setStyleSheet("QPushButton{background-image:url(./res/cancel1.png);border-radius:11px;}QPushButton:hover{background-image:url(./res/cancel1_hover.png);border-radius:11px;}")
        else:
            self.setStyleSheet("QFrame{background: rgba(46, 46, 46, 0.88);border-radius: 12px;}")
            self.name_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #F9F9F9;line-height: 17px;}")
            self.category_label.setStyleSheet("QLabel{font-size: 14px;font-weight: 400;color: #8F9399;line-height: 17px;}")
            self.down_widget.setStyleSheet("QFrame{background: #2E2E2E;border-bottom-left-radius:12px;border-bottom-right-radius:12px;border-top-left-radius:0px;border-top-right-radius:0px;}")
            self.line_label.setStyleSheet("QLabel{background-color: #8F9399;}")
            self.cancel_btn.setStyleSheet(
                "QPushButton{background-image:url(./res/cancel_dark.png);border-radius:11px;}QPushButton:hover{background-image:url(./res/cancel_hover_dark.png);border-radius:11px;}")
        self.down_progress.reflash_color()
        # QApplication.processEvents()


    #
    #函数：处理点击暂停
    #
    def slot_puase_download(self):
        if(type(self.app) != ApkInfo):
            self.puase_download.emit(self.app)
        else:
            self.puase_apk_download.emit(self.app)

        #
        # 函数：判断软件的desktop文件
        #

    def check_app_desktop(self, pkgname):
        # 对一些特殊软件单独处理

        fullcmd = ""

        desktopfile = "/usr/share/applications/" + pkgname + ".desktop"
        desktopfile1 = "/usr/share/applications/kde4/" + pkgname + ".desktop"

        if os.path.exists(desktopfile):
            return True
        elif os.path.exists(desktopfile1):
            return True
        else:
            if pkgname in Globals.PKG_NAME:
                pkgname = Globals.PKG_NAME[pkgname]

                desktopfile = "/usr/share/applications/" + pkgname + ".desktop"

                if os.path.exists(desktopfile):
                    return True
                else:
                    desktopfile = "/usr/share/applications/kde4/" + pkgname + ".desktop"
                    if (os.path.exists(desktopfile)):
                        return True
                    else:
                        return False
            else:
                return False

    def change_btn_width(self):
        s = self.m_font.boundingRect(self.btn.text()).size().width()
        if (s +18< 52):
            self.btn.setFixedSize(52,24)
        else:
            self.btn.setFixedSize(s+24,24)
        # print("00000",self.btn.width())
        self.btn.move(self.down_widget.width()-self.btn.width()-10,int((self.down_widget.height()-self.btn.height())/2))

    def change_kydroid_btn_statue(self):
        if(type(self.app) == ApkInfo):
            for i in self.mw.at.appmgr.apk_list:
                if(i.pkgname == self.app.pkgname):
                    self.app.is_installed = i.is_installed
                    self.app.is_upgradable = i.is_upgradable
            self.check_btn_text()

    #
    #函数：获取按钮的名字
    #
    def check_btn_text(self):
        self.btn.resize(52, 24)
        self.btn.move(self.down_widget.width() - self.btn.width() - 10,
                      int((self.down_widget.height() - self.btn.height()) / 2))
        self.remove_btn.stop_loading()
        self.btn.setCheckable(True)
        self.btn.setEnabled(True)
        self.remove_btn.hide()
        self.cancel_btn.hide()
        self.down_progress.hide()
        if (self.app.status == PkgStates.REMOVING):
            self.slot_uninstall(self.app.pkgname, "uninstalling")
            return
        if (type(self.app) != ApkInfo):
            try:
                self.package = self.ca[self.app.pkgname]
            except:
                self.package = None
            if (self.package != None):
                if (self.package.is_installed == True and self.package.is_upgradable == True):
                    self.btn.setText(_("update"))
                    self.change_btn_width()
                    self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;border-radius: 12px;background: rgba(55, 144, 250, 0.12);}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                elif (self.package.is_installed == False):
                    self.btn.setText(_("down"))
                    self.change_btn_width()
                    self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 12px;border-radius: 12px;border: 0px solid #3790FA;background: #3790FA;}QPushButton:hover{background: #40A9FB;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                elif (self.package.is_installed == True and self.package.is_upgradable == False):
                    if (self.app.pkgname == "kylin-installer"):
                        has_desktop = False
                    else:
                        has_desktop = self.check_app_desktop(self.app.pkgname)
                    if(has_desktop == True):
                        self.btn.setText(_("Open"))
                        self.change_btn_width()
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;border-radius: 12px;background: rgba(55, 144, 250, 0.12);}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                    else:
                        self.btn.setText(_("installed"))
                        self.change_btn_width()
                        self.btn.setEnabled(False)
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;background: rgba(55, 144, 250, 0.12);border-radius: 12px;}")
                    pass
            else:
                self.btn.setText(_("installed"))
                self.change_btn_width()
        else:
            if (self.app != None):
                if (Globals.APK_EVNRUN == 0):
                    self.btn.setText(_("start env"))
                    self.change_btn_width()
                    self.btn.setStyleSheet(
                        "QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;border-radius: 12px;background: rgba(55, 144, 250, 0.12);}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                else:
                    if (self.app.is_installed == True and self.app.is_upgradable == True):
                        self.btn.setText(_("update"))
                        self.change_btn_width()
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;border-radius: 12px;background: rgba(55, 144, 250, 0.12);}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                    elif (self.app.is_installed == False):
                        self.btn.setText(_("down"))
                        self.change_btn_width()
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 12px;border-radius: 12px;border: 0px solid #3790FA;background: #3790FA;}QPushButton:hover{background: #40A9FB;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                    elif (self.app.is_installed == True and self.app.is_upgradable == False):
                        self.btn.setText(_("Open"))
                        self.change_btn_width()
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;border-radius: 12px;background: rgba(55, 144, 250, 0.12);}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                        pass
            else:
                self.btn.setText(_("down"))
                self.change_btn_width()
                self.btn.self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #FFFFFF;line-height: 12px;border-radius: 12px;border: 0px solid #3790FA;background: #3790FA;}QPushButton:hover{background: #40A9FB;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #296CD9;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
        self.btn.show()
        self.set_btn_stylesheet()

    #
    #函数：重置按钮
    #
    def reload_btn(self,appname):
        if(appname == self.app.pkgname):
            self.check_btn_text()

    #
    #函数：进度显示
    #
    def slot_get_download_progress(self,appname,progress):
        if(appname == self.app.pkgname):
            if(progress == 100):
                self.narrow_btn_time.stop()
                self.cancel_btn.hide()
                self.btn.resize(52, 24)
                self.btn.move(self.down_widget.width() - self.btn.width() - 10,
                              int((self.down_widget.height() - self.btn.height()) / 2))
                self.btn.setCheckable(False)
                self.btn.setText(_("installing"))
                self.change_btn_width()
                self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;background: rgba(55, 144, 250, 0.12);border-radius: 12px;}")
                self.btn.show()
                self.down_progress.hide()
            else:
                self.cancel_btn.show()
                self.btn.hide()
                if (self.app.status != PkgStates.PUASE):
                    if (progress - self.pre_progress >= 2):
                        self.send_download_progress.emit(progress)
                        self.pre_progress = progress
                    else:
                        self.send_download_progress.emit(self.pre_progress)

    #
    #函数：显示下载时卡片界面的显示
    #
    def show_downloading_widget(self, appname,is_cancel=False,is_puase = False):
        if(appname == self.app.pkgname):
            if (self.app.status != PkgStates.NOTHING):
                if (is_cancel == False):
                    if(is_puase == False):
                        if (self.app.status != PkgStates.INSTALLING):
                            self.btn.hide()
                            self.cancel_btn.show()
                            self.down_progress.show()
                            self.down_progress.btn.show()
                            self.down_progress.cont_btn.hide()
                    else:
                        self.btn.setText(_("cont"))
                        self.change_btn_width()
                        self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #3790FA;line-height: 12px;border-radius: 12px;background: rgba(55, 144, 250, 0.12);}QPushButton:hover{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}QPushButton:pressed{background: #3790FA;border-radius: 12px;color: #ffffff;font-weight: 400;border:0px;}")
                        self.btn.hide()
                        self.cancel_btn.show()
                        self.down_progress.show()
                else:
                    self.btn.resize(52, 24)
                    self.btn.move(self.width() - self.btn.width() - 20, self.height() - self.btn.height() - 20)
                    self.btn.show()
                    self.reload_btn(appname)
                    self.cancel_btn.hide()
                    self.down_progress.hide()
                self.send_download_progress.emit(self.app.percent)
            else:
                self.check_btn_text()

    def slot_uninstall(self,appname,state):
        if (appname == self.app.pkgname):
            self.btn.resize(52, 24)
            self.btn.move(self.down_widget.width() - self.btn.width() - 10,
                          int((self.down_widget.height() - self.btn.height()) / 2))
            self.cancel_btn.hide()
            self.down_progress.hide()
            if (state == "uninstalling"):
                self.btn.setText(_("uninstalling"))
                self.change_btn_width()
                self.btn.hide()
                self.remove_btn.start_loading()
                self.remove_btn.show()
            else:
                self.btn.setText(_("uninstalled"))
                self.change_btn_width()
                self.btn.setStyleSheet("QPushButton{font-size: 14px;font-weight: 400;color: #F8F8F8;line-height: 12px;text-align: center;background: #C0C4CC;border-radius: 12px;}")

    def change_btn_state(self,appname,state):
        if(appname == self.app.pkgname):
            if(state == PkgStates.NOTHING or state == PkgStates.REMOVED):
                self.app.status = PkgStates.NOTHING
                self.check_btn_text()
                self.check_all_check_statue.emit()
            if(state == PkgStates.INSTALLING):
                self.slot_get_download_progress(appname,100)
            if(state == PkgStates.REMOVING):
                self.slot_uninstall(appname,"uninstalling")
            if(state == PkgStates.INSTALLED):
                self.app.is_installed = True
                self.app.is_upgradable = False
                self.app.status = PkgStates.NOTHING
                self.reload_btn(appname)
                self.check_all_check_statue.emit()
            if(state == PkgStates.DOWNLOADING):
                if (self.btn.isHidden() == False):
                    self.down_progress.init_down = True
                    self.down_progress.persent = 0
                    self.pre_progress = 0
                if (self.app.status != PkgStates.NOTHING):
                    if (self.btn.text() != ""):
                        self.narrow_btn_time.start(1)
                    else:
                        self.btn.hide()
                        self.cancel_btn.show()
                        self.down_progress.btn.show()
                        self.down_progress.cont_btn.hide()
                        self.down_progress.show()
                # self.show_downloading_widget(appname)
            if (state == PkgStates.PUASE):
                # self.show_downloading_widget(appname,False,True)
                self.app.status = PkgStates.PUASE
                self.btn.hide()
                self.cancel_btn.show()
                self.down_progress.show()
                self.down_progress.puase_download(self.app.percent)
                self.check_all_check_statue.emit()

    def move_btn(self):
        self.narrow_btn_time.stop()
        self.btn.setText("")
        w = self.btn.width()
        h = self.btn.height()
        x = self.btn.x()
        y = self.btn.y()
        if (self.app.status != PkgStates.NOTHING):
            if(self.btn.width()>self.btn.height()):
                self.btn.hide()
                self.btn.setFixedSize(w-1,h)
                self.btn.move(x+1,y)
                self.cancel_btn.hide()
                self.down_progress.hide()
                self.btn.show()
                self.narrow_btn_time.start(4)
            else:
                self.show_downloading_widget(self.app.pkgname)

    #
    # 函数：刷新背景颜色
    #
    def refresh_background_color(self):

        if (Globals.THEME_COLOR == 0):
            self.setStyleSheet("QFrame{border:0px solid #ff0000;border-radius: 12px;background-color:#999999;}")
        else:

            self.setStyleSheet("QFrame{border:0px solid #ff0000;border-radius: 12px;background-color:#999999;}")

    # 鼠标进入事件
    def enterEvent(self, event):
        self.status = BUTTON_ENTER
        self.setGeometry(self.x(), self.y(), self.width() , self.height())
        self.hover_widget.show()
        self.shadow = QGraphicsDropShadowEffect(self)
        self.shadow.setOffset(0, 0)
        self.shadow.setColor(QColor(qRgba(149,149,149,0)))
        self.shadow.setBlurRadius(20)
        self.setGraphicsEffect(self.shadow)

    #
    # 函数：鼠标离开事件
    #

    def leaveEvent(self, event):
        self.status = BUTTON_LEAVE
        self.hover_widget.hide()
        self.resize(self.width(),self.height())
        self.shadow = QGraphicsDropShadowEffect(self)
        self.shadow.setBlurRadius(0)
        self.shadow.setOffset(0, 0)
        self.setGraphicsEffect(self.shadow)

    #
    # 函数：鼠标按下事件
    #
    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:
            self.status = BUTTON_PRESSED
            if (type(self.app) == ApkInfo):
                self.clicked_kycard.emit(self.app)
            else:
                self.clicked_card.emit(self.app)
        else:
            event.ignore()


# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'login_ui.ui'
#
# Created by: PyQt5 UI code generator 4.11.4
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from models.globals import *
import math
try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QApplication.translate(context, text, disambig)

class Cutaway(QPushButton):
    ui_login_image_code_move = pyqtSignal(int)
    ui_login_mouse_current_position = pyqtSignal(int)
    def __init__(self,parent):
        QPushButton.__init__(self, parent)
        self.leave_btn = True
        self.m_parent = parent
        self.setFocusPolicy(Qt.NoFocus)
        pass

    #
    # 函数：实现无标题栏窗口拖动
    #
    def mousePressEvent(self, event):
        if (event.button() == Qt.LeftButton):
            self.mouse_press = True
            if(self.leave_btn == False):
                try:
                    self.drag_pos = event.globalPos() - self.pos()
                except:
                    pass
            event.accept()


    def mouseReleaseEvent(self, event):
        self.mouse_press = False
        if(hasattr(self,"pos")):
            if(hasattr(self.pos,"x") and self.pos.x() > 0):
                self.ui_login_mouse_current_position.emit(self.pos.x())
        self.setWindowOpacity(1)

    def mouseMoveEvent(self, event):
        if (self.mouse_press):
            self.move_pos = event.globalPos()
            self.pos = self.move_pos - self.drag_pos
            # self.move(self.move_pos - self.drag_pos)
            if(self.pos.x() <=0 ):
                pass
            elif(self.pos.x() > self.m_parent.width()-self.width()):
                pass
            else:
                self.ui_login_image_code_move.emit(self.pos.x())
            self.setWindowOpacity(1)
            event.accept()

    def enterEvent(self, event):
        self.leave_btn = False

    def leaveEvent(self, event):
        self.leave_btn = True



class Ui_Login_ui(object):
    def setupUi(self, Login_ui):
        Login_ui.setObjectName(_fromUtf8("Login_ui"))
        Login_ui.resize(484, 404)
        self.centralwidget = QFrame(Login_ui)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.centralwidget.setAttribute(QtCore.Qt.WA_TranslucentBackground)
        self.centralwidget.setGeometry(QtCore.QRect(10, 10, 464, 394))
        self.sourceWidget = QWidget(self.centralwidget)
        self.sourceWidget.setGeometry(QtCore.QRect(10, 10, 444, 374))
        self.sourceWidget.setObjectName(_fromUtf8("sourceWidget"))
        if(Globals.RIGHT_ANGLE):
            self.sourceWidget.setStyleSheet(".QWidget#sourceWidget{border:0px solid #FFFFFF;background-color:#ffffff;}")
        else:
            self.sourceWidget.setStyleSheet(".QWidget#sourceWidget{border:0px solid #FFFFFF;background-color:#ffffff;border-radius:4px;}")

        #其余异常提醒，
        self.tips_user_password = QLabel(self.sourceWidget)
        self.tips_user_password.setAttribute(Qt.WA_TranslucentBackground)
        self.tips_user_password.setGeometry(QtCore.QRect(0, 62, 444, 16))
        self.tips_user_password.setObjectName(_fromUtf8("tips_user_password"))
        self.tips_user_password.hide()

        #应用商店登录中心
        self.soft_linedit = QLabel(self.sourceWidget)
        self.soft_linedit.setAttribute(Qt.WA_TranslucentBackground)
        self.soft_linedit.setGeometry(QtCore.QRect(0, 30, 444, 22))
        self.soft_linedit.setObjectName(_fromUtf8("soft_linedit"))
        #图片验证码登录
        self.picture_widget = QWidget(self.sourceWidget)
        # self.picture_widget.setAttribute(Qt.WA_TranslucentBackground)
        self.picture_widget.setGeometry(QtCore.QRect(62, 132, 320, 212))
        self.picture_widget.setObjectName(_fromUtf8("soft_linedit"))

        # 图片验证码登录的遮盖效果
        self.picture_widget_cover = QWidget(self.picture_widget)
        self.picture_widget_cover.setAttribute(Qt.WA_StyledBackground)
        # self.picture_widget_cover.setWindowFlags(QtCore.Qt.FramelessWindowHint)
        # self.picture_widget_cover.setWindowOpacity(0.5)
        self.picture_widget_cover.setGeometry(QtCore.QRect(0, 20, 320, 160))
        self.picture_widget_cover.setObjectName(_fromUtf8("soft_linedit"))

        self.picture_tip = QLabel(self.picture_widget)
        self.picture_tip.setAttribute(Qt.WA_TranslucentBackground)
        self.picture_tip.setGeometry(QtCore.QRect(0, 0, 320, 16))
        self.picture_tip.setObjectName(_fromUtf8("soft_linedit"))

        self.picture_test_background = QLabel(self.picture_widget)
        # self.picture_test.setAttribute(Qt.WA_TranslucentBackground)
        self.picture_test_background.setGeometry(QtCore.QRect(0, 20, 320, 160))
        self.picture_test_background.setObjectName(_fromUtf8("picture_test_background"))

        self.picture_test = QLabel(self.picture_test_background)
        # self.picture_test.setAttribute(Qt.WA_TranslucentBackground)
        self.picture_test.setGeometry(QtCore.QRect(0, 0, 320, 160))
        self.picture_test.setObjectName(_fromUtf8("picture_test"))



        # self.picture_widget_corrrect = QWidget(self.picture_widget)
        # self.picture_widget_corrrect.setAttribute(Qt.WA_TranslucentBackground)
        # self.picture_widget_corrrect.setGeometry(QtCore.QRect(62, 113, 320, 212))
        # self.picture_widget_corrrect.setObjectName(_fromUtf8("soft_linedit"))

        self.picture_test_small = Cutaway(self.picture_widget)
        # self.picture_test.setAttribute(Qt.WA_TranslucentBackground)
        self.picture_test_small.setGeometry(QtCore.QRect(0, 20, 50, 160))
        self.picture_test_small.setObjectName(_fromUtf8("picture_test"))

        # self.picture_back = QLabel(self.picture_widget)
        # # self.picture_test.setAttribute(Qt.WA_TranslucentBackground)
        # self.picture_back.setGeometry(QtCore.QRect(0, 20, 320, 160))
        # self.picture_back.setObjectName(_fromUtf8("picture_test"))

        self.picture_correct = QLabel(self.picture_widget)
        self.picture_correct.setGeometry(QtCore.QRect(125, 65, 70, 70))
        # self.picture_correct.setAttribute(Qt.WA_TranslucentBackground)

        self.picture_bar = QWidget(self.picture_widget)
        self.picture_bar.setGeometry(QtCore.QRect(0,194,320,10))
        self.picture_test.setObjectName(_fromUtf8("picture_bar"))
        #
        # self.picture_bar_slide = QPushButton(self.picture_widget)
        # self.picture_bar_slide.setGeometry(QtCore.QRect(0, 185, 48, 26))
        # self.picture_test.setObjectName(_fromUtf8("picture_bar_slide"))
        # 用户名错误时显示
        self.tips_user=QLabel(self.sourceWidget)
        self.tips_user.setAttribute(Qt.WA_TranslucentBackground)
        self.tips_user.setGeometry(QtCore.QRect(278, 141, 84, 16))
        self.tips_user.setObjectName(_fromUtf8("tips_user"))
        self.tips_user.hide()
        # 密码错误
        self.tips_password = QLabel(self.sourceWidget)
        self.tips_password.setAttribute(Qt.WA_TranslucentBackground)
        self.tips_password.setGeometry(QtCore.QRect(315, 192, 48, 16))
        self.tips_password.setObjectName(_fromUtf8("tips_password"))
        self.tips_password.hide()

        #手机号错误提示
        self.tips_num=QLabel(self.sourceWidget)
        self.tips_num.setAttribute(Qt.WA_TranslucentBackground)
        self.tips_num.setGeometry(QtCore.QRect(315, 141, 48, 16))
        self.tips_num.setObjectName(_fromUtf8("tips_user"))
        self.tips_num.hide()

        # 密码登录
        self.btnPassword = QPushButton(self.sourceWidget)
        self.btnPassword.setAttribute(Qt.WA_TranslucentBackground)
        self.btnPassword.setGeometry(QtCore.QRect(132, 86, 80, 24))
        self.btnPassword.setText(_fromUtf8(""))

        # 短信登录
        self.btnShortMessage = QPushButton(self.sourceWidget)
        self.btnShortMessage.setAttribute(Qt.WA_TranslucentBackground)
        self.btnShortMessage.setGeometry(QtCore.QRect(232, 86, 80, 24))
        self.btnShortMessage.setText(_fromUtf8(""))


        # 登录用户框
        self.Login_user_box=QWidget(self.sourceWidget)
        self.Login_user_box.setGeometry(QtCore.QRect(82, 177, 280, 1))
        self.Login_user_box.setObjectName(_fromUtf8("Login_user_box"))

        # 手机号框
        self.Login_phone_box=QWidget(self.sourceWidget)
        self.Login_phone_box.setGeometry(QtCore.QRect(82, 177, 280, 1))
        self.Login_phone_box.setObjectName(_fromUtf8("Login_phone_box"))

        # 登录密码框
        self.Login_pwd_box = QWidget(self.sourceWidget)
        self.Login_pwd_box.setGeometry(QtCore.QRect(82, 228, 280, 1))
        self.Login_pwd_box.setObjectName(_fromUtf8("Login_pwd_box"))

        # 短信输入框
        self.Login_sm_box = QWidget(self.sourceWidget)
        self.Login_sm_box.setGeometry(QtCore.QRect(82, 228, 280, 1))
        self.Login_sm_box.setObjectName(_fromUtf8("Login_sm_box"))

        # 密码登录界面的用户名框文字
        self.lesource = QLineEdit(self.sourceWidget)
        self.lesource.setFocus(True)
       # self.lesource.setAttribute(Qt.WA_Hover,True)
        self.lesource.setAttribute(Qt.WA_TranslucentBackground)
        self.lesource.setGeometry(QtCore.QRect(109, 150, 200, 20))
        self.lesource.setObjectName(_fromUtf8("lesource"))

        # 密码登录界面的用户框背景文字
        self.lesource_M_back = QLabel(self.sourceWidget)
        self.lesource_M_back.setFocus(True)
        # self.lesource.setAttribute(Qt.WA_Hover,True)
        self.lesource_M_back.setAttribute(Qt.WA_TranslucentBackground)
        self.lesource_M_back.setGeometry(QtCore.QRect(112, 150, 200, 18))
        self.lesource_M_back.setObjectName(_fromUtf8("lesource_M_back"))

        # 显示或者隐藏密码的父窗口，方便处理
        self.show_hide_pwd = QPushButton(self.sourceWidget)
        self.show_hide_pwd.setAttribute(Qt.WA_TranslucentBackground)
        self.show_hide_pwd.setGeometry(QtCore.QRect(340, 203, 16, 16))
        self.show_hide_pwd.setObjectName(_fromUtf8("show or hide pwd"))
        # 显示密码按钮
        self.show_pwd = QPushButton(self.show_hide_pwd)
        self.show_pwd.setAttribute(Qt.WA_TranslucentBackground)
        self.show_pwd.setGeometry(QtCore.QRect(0, 0, 16, 16))
        self.show_pwd.setObjectName(_fromUtf8("show pwd"))

        # 隐藏密码按钮
        self.hide_pwd = QPushButton(self.show_hide_pwd)
        self.hide_pwd.setAttribute(Qt.WA_TranslucentBackground)
        self.hide_pwd.setGeometry(QtCore.QRect(0, 0, 16, 16))
        self.hide_pwd.setObjectName(_fromUtf8("hide pwd"))

        # 用户下拉框
        self.show_search = QPushButton(self.sourceWidget)
        self.show_search.setAttribute(Qt.WA_TranslucentBackground)
        self.show_search.setGeometry(QtCore.QRect(340, 152, 16, 16))
        self.show_search.setObjectName(_fromUtf8("show search"))



        #短信登录界面的电话号码框文字
        self.lesource1 = QLineEdit(self.sourceWidget)
       # self.lesource1.setAttribute(Qt.WA_Hover, True)
        self.lesource1.setAttribute(Qt.WA_TranslucentBackground)
        self.lesource1.setGeometry(QtCore.QRect(109, 150, 264, 20))
        self.lesource1.setObjectName(_fromUtf8("lesource1"))
        self.lesource1.hide()

        self.lesource1_S_back = QLabel(self.sourceWidget)
        # self.lesource1.setAttribute(Qt.WA_Hover, True)
        self.lesource1_S_back.setAttribute(Qt.WA_TranslucentBackground)
        self.lesource1_S_back.setGeometry(QtCore.QRect(112, 150, 200, 18))
        self.lesource1_S_back.setObjectName(_fromUtf8("lesource1_S_back"))
        self.lesource1_S_back.hide()

        #用户框或者手机号框的图标
        self.usr_icon=QWidget(self.sourceWidget)
        self.usr_icon.setGeometry(QtCore.QRect(87, 152, 16, 16))
        self.usr_icon.setObjectName(_fromUtf8("usr_icon"))

        #密码登录界面的密码框背景文字
        self.lesource_2 = QLineEdit(self.sourceWidget)
        #self.lesource_2.setAttribute(Qt.WA_Hover, True)
        self.lesource_2.setAttribute(Qt.WA_TranslucentBackground)
        self.lesource_2.setGeometry(QtCore.QRect(109,201, 237, 20))
        self.lesource_2.setObjectName(_fromUtf8("lesource_2"))

        self.lesource_2_M_back = QLabel(self.sourceWidget)
        # self.lesource_2.setAttribute(Qt.WA_Hover, True)
        self.lesource_2_M_back.setAttribute(Qt.WA_TranslucentBackground)
        self.lesource_2_M_back.setGeometry(QtCore.QRect(112, 201, 200, 18))
        self.lesource_2_M_back.setObjectName(_fromUtf8("lesource_2_M_back"))

        #短信登录界面的验证码框背景文字
        self.lesource_1 = QLineEdit(self.sourceWidget)
        #self.lesource_1.setAttribute(Qt.WA_Hover, True)
        self.lesource_1.setAttribute(Qt.WA_TranslucentBackground)
        self.lesource_1.setGeometry(QtCore.QRect(109,201, 264, 20))
        self.lesource_1.setObjectName(_fromUtf8("lesource_1"))
        self.lesource_1.hide()

        self.lesource_1_S_back = QLabel(self.sourceWidget)
        # self.lesource_1.setAttribute(Qt.WA_Hover, True)
        self.lesource_1_S_back.setAttribute(Qt.WA_TranslucentBackground)
        self.lesource_1_S_back.setGeometry(QtCore.QRect(112, 201, 264, 18))
        self.lesource_1_S_back.setObjectName(_fromUtf8("lesource_1_S_back"))
        self.lesource_1_S_back.hide()

        #密码框或者验证码框的图标
        self.password_icon = QWidget(self.sourceWidget)
        self.password_icon.setGeometry(QtCore.QRect(87, 203, 16, 16))
        self.password_icon.setObjectName(_fromUtf8("password_icon"))
        #验证码分隔线
        self.separator_line = QWidget(self.sourceWidget)
        self.separator_line.setGeometry(QtCore.QRect(294, 204, 1, 14))
        self.separator_line.setObjectName(_fromUtf8("separator_line"))
        self.separator_line.hide()
        #获取验证码
        self.captcha = QPushButton(self.sourceWidget)
        self.captcha.setAttribute(Qt.WA_TranslucentBackground)
        self.captcha.setGeometry(QtCore.QRect(303,203, 64, 16))
        self.captcha.setObjectName(_fromUtf8("captcha"))
        self.captcha.hide()

        #记住密码
        self.rmb_pwd = QPushButton(self.sourceWidget)
        self.rmb_pwd.setAttribute(Qt.WA_TranslucentBackground)
        self.rmb_pwd.setGeometry(QtCore.QRect(109, 240, 65, 20))
        # self.rmb_pwd.setFixedHeight(20)
        # self.rmb_pwd.setFixedSize(58,14)
        self.rmb_pwd.setText(_fromUtf8(""))
        self.rmb_pwd.setObjectName(_fromUtf8("rmb_pwd"))


        #自动登录
        # self.text9 = QLabel(self.groupBox)
        # self.text9.setGeometry(QtCore.QRect(193,226, 70, 14))
        # self.text9.setText(_fromUtf8(""))
        # self.text9.setObjectName(_fromUtf8("text9"))
        #找回密码--改为忘记密码？
        self.forget_pwd=QPushButton(self.sourceWidget)
        self.forget_pwd.setAttribute(Qt.WA_TranslucentBackground)
        self.forget_pwd.setGeometry(QtCore.QRect(297, 240, 79, 20))
        self.forget_pwd.setText(_fromUtf8(""))
        self.forget_pwd.setObjectName(_fromUtf8("forget_pwd"))

        #登录的按钮
        self.btn_login = QPushButton(self.sourceWidget)
        self.btn_login.setAttribute(Qt.WA_TranslucentBackground)
        self.btn_login.setGeometry(QtCore.QRect(82, 292, 280, 32))
        self.btn_login.setText(_fromUtf8(""))
        self.btn_login.setObjectName(_fromUtf8("btn_login"))

        # 注册新账户
        self.register_new_account = QPushButton(self.sourceWidget)
        self.register_new_account.setAttribute(Qt.WA_TranslucentBackground)

        self.register_new_account.setGeometry(QtCore.QRect(208, self.btn_login.height() + self.btn_login.y() + 9, 28, 14))
        self.register_new_account.setFixedHeight(20)
        # self.register_new_account.setFixedHeight(20)
        # self.register_new_account.setFixedsize(80,14)
        self.register_new_account.setText(_fromUtf8(""))
        self.register_new_account.setObjectName(_fromUtf8("register_new_account"))

        # self.btn_login.setFocus(Qt.)
        #self.lesource_6 = QLineEdit(self.groupBox_2)
        #self.lesource_6.setGeometry(QtCore.QRect(100,175,200,25))
        #self.lesource_6.setObjectName(_fromUtf8("lesource_6"))
        #记住密码前面的方框
        self.checkBox_5 = QCheckBox(self.sourceWidget)
        self.checkBox_5.setGeometry(QtCore.QRect(89, 244, 14, 14))
        # 原来的自动登录前面的方框,保留备用
        # self.checkBox_6 = QCheckBox(self.sourceWidget)
        # self.checkBox_6.setGeometry(QtCore.QRect(204, 185, 18, 18))
        # self.checkBox_6.hide()
        # self.checkBox_5.setPalette(palette)

        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Serif"))
        font.setPointSize(10)


        self.btnClose = QPushButton(self.sourceWidget)
        self.btnClose.setGeometry(QtCore.QRect(410, 4, 30, 30))
        self.btnClose.setText(_fromUtf8(""))

        self.sourceWidget.raise_()
        #self.label.raise_()

        self.retranslateUi(Login_ui)
        QtCore.QMetaObject.connectSlotsByName(Login_ui)

    #
    # 函数名:设置窗口标题
    # Function:set window title
    # 
    def retranslateUi(self, Login_ui):
        Login_ui.setWindowTitle(_translate("Login_ui", "Form", None))



if __name__ == "__main__":
    import sys
    app = QApplication(sys.argv)
    Login_ui = QWidget()
    ui = Ui_Login_ui()
    ui.setupUi(Login_ui)
    Login_ui.show()
    sys.exit(app.exec_())

